type token =
  | SPEC of (int * Cast.parsed_spec)
  | DECL of (int * Cast.parsed_decl)
  | CODE_ANNOT of (int * Cast.parsed_code_annot)
  | LOOP_ANNOT of (int * Cast.parsed_loop_annot)
  | IDENTIFIER of (string)
  | CONSTANT of (string)
  | STRING_LITERAL of (string)
  | TYPE_NAME of (string)
  | SIZEOF
  | PTR_OP
  | INC_OP
  | DEC_OP
  | LEFT_OP
  | RIGHT_OP
  | LE_OP
  | GE_OP
  | EQ_OP
  | NE_OP
  | AND_OP
  | OR_OP
  | MUL_ASSIGN
  | DIV_ASSIGN
  | MOD_ASSIGN
  | ADD_ASSIGN
  | SUB_ASSIGN
  | LEFT_ASSIGN
  | RIGHT_ASSIGN
  | AND_ASSIGN
  | XOR_ASSIGN
  | OR_ASSIGN
  | TYPEDEF
  | EXTERN
  | STATIC
  | AUTO
  | REGISTER
  | CHAR
  | SHORT
  | INT
  | LONG
  | SIGNED
  | UNSIGNED
  | FLOAT
  | DOUBLE
  | CONST
  | VOLATILE
  | VOID
  | STRUCT
  | UNION
  | ENUM
  | ELLIPSIS
  | CASE
  | DEFAULT
  | IF
  | ELSE
  | SWITCH
  | WHILE
  | DO
  | FOR
  | GOTO
  | CONTINUE
  | BREAK
  | RETURN
  | SEMICOLON
  | LBRACE
  | RBRACE
  | COMMA
  | COLON
  | EQUAL
  | LPAR
  | RPAR
  | LSQUARE
  | RSQUARE
  | DOT
  | AMP
  | EXL
  | TILDE
  | MINUS
  | PLUS
  | STAR
  | SLASH
  | PERCENT
  | LT
  | GT
  | HAT
  | PIPE
  | QUESTION
  | EOF
  | ATTRIBUTE
  | RESTRICT

open Parsing;;
# 20 "c/cparser.mly"

  open Format
  open Coptions
  open Ptree
  open Cast
  open Parsing

  let loc () = (symbol_start (), symbol_end ())
  let loc_i i = (rhs_start i, rhs_end i)

  let locate x = { node = x; loc = loc() }
  let locate_i i x = { node = x; loc = loc_i i }
  let with_loc l x = { node = x; loc = l }

  let error s = raise (Stdpp.Exc_located (loc (), Stream.Error s))

  let uns () =
    raise (Stdpp.Exc_located (loc (), Stream.Error "Unsupported C syntax"))
  let unss s =
    raise (Stdpp.Exc_located (loc (), 
			      Stream.Error ("Unsupported C syntax: " ^ s)))
  let warning s =
    Format.eprintf "%a warning: %s\n" Loc.report_line (symbol_start ()) s
  let vwarning s = if verbose then warning s
  let dwarning s = if debug then warning s

  let no_loop_annot = 
    { Clogic.invariant = None; 
      Clogic.loop_assigns = None;
      Clogic.variant = None }

  let add_pre_loc lb = function
    | Some (b,_) -> Loc.join (b,0) lb 
    | _ -> lb

  let expr_of_statement s = match s.node with
    | CSnop -> { node = CEnop; loc = s.loc }
    | CSexpr e -> e
    | _ -> assert false

  (* used only for parsing types *)

  type specifier = 
    | Stypedef 
    | Sstorage of storage_class
    | Stype of cexpr ctype_node
    | Slong
    | Sshort
    | Sconst
    | Svolatile
    | Srestrict
    | Ssign of sign
    | Sstruct_decl of string option * fields
    | Sunion_decl of string option * fields
	
  and specifiers = specifier list

  and declarator =
    | Dsimple
    | Dpointer of declarator
    | Darray of declarator * cexpr option
    | Dfunction of declarator * parameters

  and parameters = (specifiers * declarator * string) list

  and fields = (specifiers * declarator * string * cexpr option) list

  (* interps a list of specifiers / declarators as a [ctype] *)
  (* TODO: short/long *)

  let storage_class = 
    let rec loop st = function
      | [] -> 
	  st
      | Sstorage st' :: s when st = No_storage -> 
	  loop st' s
      | Sstorage st' :: s when st' = st ->
	  warning "duplicate storage class"; loop st s
      | Sstorage st' :: _ ->
	  error "multiple storage class"
      | _ :: s -> 
	  loop st s
    in
    loop No_storage

  let sign =
    let rec loop so = function
      | [] -> 
	  so
      | Ssign b' :: sp -> 
	  (match so with 
	     | None -> loop (Some b') sp
	     | Some b when b = b' -> warning "duplicate (un)signed"; loop so sp
	     | Some b -> error "both signed and unsigned")
      | _ :: sp -> 
	  loop so sp
    in
    loop None

  let apply_sign sg ty = match sg, ty with
    | None, t -> t
    | Some b, (CTint (_, i)) -> CTint (b, i)
    | Some _, _ -> error "signed or unsigned invalid"

  type length = Short | Long | LongLong

  let length =
    let rec loop lo = function
      | [] -> 
	  lo
      | (Sshort | Slong as s) :: sp -> 
	  (match s, lo with 
	     | Sshort, None -> 
		 loop (Some Short) sp
	     | Slong, None -> 
		 loop (Some Long) sp
	     | Sshort, Some Short -> 
		 warning "duplicate short"; loop lo sp
	     | Sshort, Some (Long | LongLong) | Slong, Some Short -> 
		 error "both long and short specified"
	     | Slong, Some Long -> 
		 loop (Some LongLong) sp
	     | Slong, Some LongLong ->
		 error "too long for caduceus"
	     | _ -> 
		 assert false)
      | _ :: sp -> 
	  loop lo sp
    in
    loop None

  (* debug *)
  let rec explain_type fmt = function
    | CTfun (_, t) -> 
	fprintf fmt "function returning %a" explain_type t.ctype_node
    | CTpointer t -> 
	fprintf fmt "pointer on %a" explain_type t.ctype_node
    | CTarray (t, _) -> 
	fprintf fmt "array[] of %a" explain_type t.ctype_node
    | _ -> 
	fprintf fmt "other"

  (* fresh names for anonymous structures *)

  let fresh_name =
    let r = ref (-1) in
    function 
      | Some s -> s
      | None -> incr r; "%_anonymous_" ^ string_of_int !r

  (* Interpretation of type expression.
     [gl] indicates a global declaration (implies the check for a type or 
     a storage class) *)

  let rec interp_type gl specs decl = 
    let st = storage_class specs in
    let cst = List.exists ((=) Sconst) specs in
    let vl = List.exists ((=) Svolatile) specs in
    let sg = sign specs in
    let lg = length specs in
    let noattr n = { ctype_node = n; ctype_storage = No_storage;
		     ctype_const = false; ctype_volatile = false } in
    let rec base_type tyo = function
      | [] -> 
	  (match tyo with 
	     | Some ty -> ty 
	     | None when gl && st = No_storage && sg = None && lg = None -> 
		 error "data definition has no type or storage class"
	     | None -> match lg with
		 | None -> CTint (Signed, Int)
		 | Some Short -> CTint (Signed, Cast.Short)
		 | Some Long -> CTint (Signed, Cast.Long)
		 | Some LongLong -> CTint (Signed, Cast.LongLong))
      | Stype t :: sp when tyo = None ->
	  base_type (Some t) sp
      | Sstruct_decl (so, pl) :: sp when tyo = None ->
	  base_type (Some (CTstruct (fresh_name so, Decl (fields pl)))) sp
      | Sunion_decl (so, pl) :: sp when tyo = None ->
	  base_type (Some (CTunion (fresh_name so, Decl (fields pl)))) sp
      | (Stype _ | Sstruct_decl _ | Sunion_decl _) :: _ ->
	  error "two or more data types in declaration"
      | _ :: sp ->
	  base_type tyo sp
    and full_type ty = function
      | Dsimple -> ty
      | Dpointer d -> full_type (noattr (CTpointer ty)) d
      | Darray (d, so) -> full_type (noattr (CTarray (ty, so))) d
      | Dfunction (d, pl) -> full_type (noattr (CTfun (params pl, ty))) d
    and params pl = 
      List.map (fun (s,d,x) -> (interp_type false s d, x)) pl
    and fields fl =
      List.map (fun (s,d,x,bf) -> (interp_type false s d, x, bf)) fl
    in
    let bt = base_type None specs in
    let bt = apply_sign sg bt in
    let bt = { ctype_node = bt; ctype_storage = st;
	       ctype_const = cst; ctype_volatile = vl } 
    in
    let ty = full_type bt decl in
    if debug then eprintf "%a@." explain_type ty.ctype_node;
    ty

  let interp_param (s, d, id) = interp_type false s d, id
  let interp_params = List.map interp_param

  let is_typedef = List.exists ((=) Stypedef)

  let declaration specs decls =
    let l = loc() in
    if is_typedef specs then
      let interp = function
	| (n,d), Inothing -> 
	    Ctypes.add n; Ctypedef (interp_type true specs d, n)
	| (n,_), _ -> 
	    error ("typedef " ^ n ^ " is initialized")
      in
      List.map interp decls
    else
      let interp ((n,d),i) =
	Ctypes.remove n; Cdecl (interp_type true specs d, n, i)
      in
      List.map interp decls

  let spec_declaration s specs decls =
    match declaration specs decls with
      | [Cdecl ({ ctype_node = CTfun (pl, ty) }, f, _)] ->
	  Cfunspec (s, ty, f, pl)
      | _ ->
	  raise Parsing.Parse_error

  let type_declarations specs =
    if is_typedef specs then warning "useless keyword in empty declaration";
    let ty = interp_type true specs Dsimple in
    match ty.ctype_node with
      | CTstruct _ | CTunion _ | CTenum _ ->
          [ locate (Ctypedecl ty) ]
      | _ ->
	  warning "empty declaration";
	  []

  (* old style function prototype: f(x,y,z) t1 x; t2 y; ...
     some parameters may be omitted *)
  let old_style_params pl decls =
    let pids = List.map (fun (_,x) -> x) pl in
    let h = Hashtbl.create 17 in
    (* we first check that no parameter is initialized or occurs twice *)
    List.iter
      (fun d -> match d.node with
	 | Cdecl (ty, x, Inothing) -> 
	     if not (List.mem x pids) then 
	       error ("declaration for " ^ x ^ " but no such parameter");
	     if Hashtbl.mem h x then error ("duplicate declaration for " ^ x);
	     Hashtbl.add h x ty
	 | Cdecl (_,x,_) -> error ("parameter " ^ x ^ " is initialized")
	 | _ -> ()) 
      decls;
    (* do it for all parameters *)
    List.map (fun (tx, x) -> (try Hashtbl.find h x with Not_found -> tx), x) pl

  let function_declaration specs (id,d) decls = 
    let ty = interp_type false specs d in
    match ty.ctype_node with
      | CTfun (pl, tyf) ->
	  let pl = 
	    if decls = [] then pl else old_style_params pl decls 
	  in
	  List.iter (fun (_,x) -> Ctypes.remove x) pl;
	  tyf, id, pl
      | _ -> 
	  raise Parsing.Parse_error

# 366 "c/cparser.ml"
let yytransl_const = [|
  265 (* SIZEOF *);
  266 (* PTR_OP *);
  267 (* INC_OP *);
  268 (* DEC_OP *);
  269 (* LEFT_OP *);
  270 (* RIGHT_OP *);
  271 (* LE_OP *);
  272 (* GE_OP *);
  273 (* EQ_OP *);
  274 (* NE_OP *);
  275 (* AND_OP *);
  276 (* OR_OP *);
  277 (* MUL_ASSIGN *);
  278 (* DIV_ASSIGN *);
  279 (* MOD_ASSIGN *);
  280 (* ADD_ASSIGN *);
  281 (* SUB_ASSIGN *);
  282 (* LEFT_ASSIGN *);
  283 (* RIGHT_ASSIGN *);
  284 (* AND_ASSIGN *);
  285 (* XOR_ASSIGN *);
  286 (* OR_ASSIGN *);
  287 (* TYPEDEF *);
  288 (* EXTERN *);
  289 (* STATIC *);
  290 (* AUTO *);
  291 (* REGISTER *);
  292 (* CHAR *);
  293 (* SHORT *);
  294 (* INT *);
  295 (* LONG *);
  296 (* SIGNED *);
  297 (* UNSIGNED *);
  298 (* FLOAT *);
  299 (* DOUBLE *);
  300 (* CONST *);
  301 (* VOLATILE *);
  302 (* VOID *);
  303 (* STRUCT *);
  304 (* UNION *);
  305 (* ENUM *);
  306 (* ELLIPSIS *);
  307 (* CASE *);
  308 (* DEFAULT *);
  309 (* IF *);
  310 (* ELSE *);
  311 (* SWITCH *);
  312 (* WHILE *);
  313 (* DO *);
  314 (* FOR *);
  315 (* GOTO *);
  316 (* CONTINUE *);
  317 (* BREAK *);
  318 (* RETURN *);
  319 (* SEMICOLON *);
  320 (* LBRACE *);
  321 (* RBRACE *);
  322 (* COMMA *);
  323 (* COLON *);
  324 (* EQUAL *);
  325 (* LPAR *);
  326 (* RPAR *);
  327 (* LSQUARE *);
  328 (* RSQUARE *);
  329 (* DOT *);
  330 (* AMP *);
  331 (* EXL *);
  332 (* TILDE *);
  333 (* MINUS *);
  334 (* PLUS *);
  335 (* STAR *);
  336 (* SLASH *);
  337 (* PERCENT *);
  338 (* LT *);
  339 (* GT *);
  340 (* HAT *);
  341 (* PIPE *);
  342 (* QUESTION *);
    0 (* EOF *);
  343 (* ATTRIBUTE *);
  344 (* RESTRICT *);
    0|]

let yytransl_block = [|
  257 (* SPEC *);
  258 (* DECL *);
  259 (* CODE_ANNOT *);
  260 (* LOOP_ANNOT *);
  261 (* IDENTIFIER *);
  262 (* CONSTANT *);
  263 (* STRING_LITERAL *);
  264 (* TYPE_NAME *);
    0|]

let yylhs = "\255\255\
\001\000\001\000\003\000\003\000\003\000\003\000\005\000\005\000\
\005\000\005\000\005\000\005\000\005\000\005\000\006\000\006\000\
\009\000\009\000\009\000\009\000\009\000\009\000\010\000\010\000\
\010\000\010\000\010\000\010\000\011\000\011\000\013\000\013\000\
\013\000\013\000\014\000\014\000\014\000\015\000\015\000\015\000\
\016\000\016\000\016\000\016\000\016\000\017\000\017\000\017\000\
\018\000\018\000\019\000\019\000\020\000\020\000\021\000\021\000\
\022\000\022\000\023\000\023\000\008\000\008\000\024\000\024\000\
\024\000\024\000\024\000\024\000\024\000\024\000\024\000\024\000\
\024\000\004\000\004\000\025\000\026\000\026\000\026\000\026\000\
\027\000\027\000\027\000\027\000\027\000\027\000\032\000\032\000\
\032\000\032\000\032\000\032\000\028\000\028\000\035\000\035\000\
\030\000\030\000\030\000\030\000\030\000\031\000\031\000\034\000\
\034\000\034\000\034\000\034\000\034\000\034\000\034\000\034\000\
\034\000\034\000\007\000\007\000\038\000\038\000\038\000\040\000\
\040\000\041\000\041\000\042\000\043\000\043\000\043\000\043\000\
\045\000\045\000\045\000\045\000\044\000\044\000\046\000\046\000\
\046\000\039\000\039\000\039\000\047\000\047\000\048\000\048\000\
\033\000\033\000\033\000\036\000\036\000\050\000\050\000\050\000\
\050\000\050\000\050\000\050\000\053\000\053\000\049\000\049\000\
\049\000\049\000\054\000\054\000\051\000\051\000\055\000\055\000\
\056\000\056\000\056\000\052\000\052\000\012\000\012\000\057\000\
\057\000\057\000\058\000\058\000\058\000\058\000\058\000\058\000\
\058\000\058\000\058\000\037\000\037\000\037\000\059\000\059\000\
\060\000\060\000\060\000\060\000\060\000\060\000\060\000\061\000\
\061\000\061\000\062\000\062\000\062\000\062\000\067\000\069\000\
\069\000\068\000\068\000\063\000\063\000\063\000\064\000\064\000\
\064\000\065\000\065\000\065\000\065\000\066\000\066\000\066\000\
\066\000\066\000\002\000\002\000\070\000\070\000\071\000\071\000\
\072\000\072\000\072\000\072\000\029\000\029\000\073\000\073\000\
\074\000\075\000\075\000\076\000\076\000\076\000\076\000\076\000\
\000\000"

let yylen = "\002\000\
\002\000\001\000\001\000\001\000\001\000\003\000\001\000\004\000\
\003\000\004\000\003\000\003\000\002\000\002\000\001\000\003\000\
\001\000\002\000\002\000\002\000\002\000\004\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\004\000\001\000\003\000\
\003\000\003\000\001\000\003\000\003\000\001\000\003\000\003\000\
\001\000\003\000\003\000\003\000\003\000\001\000\003\000\003\000\
\001\000\003\000\001\000\003\000\001\000\003\000\001\000\003\000\
\001\000\003\000\001\000\005\000\001\000\003\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\003\000\001\000\002\000\004\000\005\000\001\000\
\001\000\002\000\001\000\002\000\001\000\002\000\001\000\002\000\
\001\000\002\000\001\000\002\000\001\000\003\000\001\000\003\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\001\000\001\000\001\000\001\000\
\001\000\001\000\001\000\001\000\005\000\004\000\002\000\001\000\
\001\000\001\000\002\000\003\000\002\000\001\000\002\000\001\000\
\002\000\001\000\002\000\001\000\001\000\003\000\001\000\002\000\
\003\000\004\000\005\000\002\000\001\000\003\000\001\000\003\000\
\001\000\001\000\001\000\002\000\001\000\001\000\003\000\004\000\
\003\000\004\000\004\000\003\000\001\000\000\000\001\000\002\000\
\002\000\003\000\001\000\002\000\001\000\003\000\001\000\003\000\
\002\000\002\000\001\000\001\000\003\000\001\000\002\000\001\000\
\001\000\002\000\003\000\002\000\003\000\003\000\004\000\002\000\
\003\000\003\000\004\000\001\000\003\000\004\000\001\000\003\000\
\001\000\001\000\001\000\001\000\001\000\001\000\002\000\003\000\
\004\000\003\000\002\000\003\000\003\000\004\000\001\000\001\000\
\002\000\001\000\002\000\001\000\001\000\002\000\005\000\007\000\
\005\000\006\000\008\000\007\000\008\000\003\000\002\000\002\000\
\002\000\003\000\001\000\002\000\001\000\001\000\002\000\003\000\
\003\000\002\000\002\000\001\000\000\000\001\000\001\000\002\000\
\006\000\001\000\003\000\000\000\001\000\003\000\004\000\001\000\
\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\080\000\115\000\000\000\097\000\098\000\
\099\000\100\000\101\000\105\000\106\000\107\000\108\000\111\000\
\112\000\109\000\110\000\145\000\146\000\104\000\120\000\121\000\
\000\000\000\000\000\000\002\000\147\000\249\000\000\000\150\000\
\230\000\000\000\000\000\000\000\000\000\102\000\000\000\113\000\
\114\000\000\000\000\000\000\000\227\000\229\000\000\000\000\000\
\000\000\116\000\000\000\000\000\000\000\163\000\161\000\000\000\
\001\000\228\000\077\000\000\000\093\000\000\000\103\000\082\000\
\000\000\084\000\000\000\000\000\086\000\000\000\208\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\207\000\231\000\
\000\000\000\000\232\000\000\000\000\000\141\000\000\000\151\000\
\164\000\162\000\000\000\000\000\000\000\000\000\239\000\000\000\
\000\000\088\000\092\000\090\000\000\000\000\000\209\000\000\000\
\000\000\000\000\122\000\000\000\000\000\172\000\156\000\000\000\
\000\000\000\000\000\000\167\000\003\000\004\000\005\000\000\000\
\000\000\000\000\000\000\153\000\023\000\028\000\027\000\026\000\
\025\000\024\000\007\000\000\000\029\000\000\000\031\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\076\000\000\000\000\000\213\000\157\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\212\000\
\203\000\000\000\000\000\074\000\000\000\061\000\000\000\210\000\
\193\000\194\000\195\000\196\000\197\000\198\000\000\000\000\000\
\000\000\000\000\138\000\000\000\000\000\094\000\000\000\078\000\
\240\000\000\000\188\000\096\000\000\000\000\000\125\000\127\000\
\118\000\123\000\000\000\000\000\000\000\133\000\000\000\000\000\
\000\000\169\000\000\000\170\000\000\000\154\000\000\000\155\000\
\000\000\000\000\021\000\000\000\018\000\019\000\000\000\000\000\
\000\000\000\000\013\000\014\000\000\000\000\000\000\000\020\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\152\000\000\000\199\000\000\000\000\000\
\000\000\000\000\000\000\223\000\224\000\225\000\000\000\214\000\
\000\000\000\000\064\000\065\000\066\000\067\000\068\000\069\000\
\070\000\071\000\072\000\073\000\063\000\000\000\000\000\000\000\
\000\000\204\000\211\000\205\000\000\000\079\000\144\000\142\000\
\139\000\000\000\191\000\000\000\131\000\129\000\136\000\000\000\
\124\000\000\000\117\000\184\000\000\000\000\000\180\000\000\000\
\000\000\000\000\000\000\173\000\166\000\168\000\000\000\006\000\
\000\000\000\000\000\000\175\000\012\000\009\000\000\000\015\000\
\000\000\011\000\032\000\033\000\034\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\202\000\000\000\
\000\000\222\000\226\000\075\000\200\000\062\000\000\000\000\000\
\000\000\206\000\248\000\000\000\000\000\242\000\189\000\000\000\
\137\000\134\000\185\000\179\000\181\000\186\000\000\000\182\000\
\000\000\022\000\030\000\000\000\010\000\008\000\000\000\201\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\190\000\192\000\187\000\183\000\016\000\060\000\000\000\217\000\
\000\000\000\000\000\000\246\000\000\000\243\000\241\000\000\000\
\218\000\000\000\000\000\000\000\247\000\216\000\000\000\220\000\
\000\000\219\000\221\000"

let yydgoto = "\002\000\
\030\000\031\000\131\000\162\000\132\000\055\001\163\000\164\000\
\165\000\134\000\135\000\216\000\136\000\137\000\138\000\139\000\
\140\000\141\000\142\000\143\000\144\000\145\000\166\000\014\001\
\147\000\071\000\072\000\060\000\093\000\035\000\036\000\066\000\
\037\000\038\000\061\000\039\000\188\000\040\000\041\000\042\000\
\106\000\107\000\108\000\197\000\191\000\198\000\085\000\086\000\
\043\000\044\000\037\001\114\000\167\000\056\000\115\000\116\000\
\038\001\205\000\028\001\168\000\169\000\170\000\171\000\172\000\
\173\000\174\000\081\000\175\000\073\000\045\000\046\000\047\000\
\094\000\095\000\093\001\094\001"

let yysindex = "\025\000\
\003\000\000\000\146\003\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\052\255\084\255\121\255\000\000\000\000\000\000\061\000\000\000\
\000\000\024\255\103\004\155\009\103\004\000\000\151\002\000\000\
\000\000\060\255\048\255\231\254\000\000\000\000\210\254\084\255\
\210\254\000\000\029\255\010\255\245\254\000\000\000\000\121\255\
\000\000\000\000\000\000\242\254\000\000\135\000\000\000\000\000\
\155\009\000\000\103\004\155\009\000\000\103\004\000\000\024\255\
\151\002\007\001\015\255\231\254\165\003\149\002\000\000\000\000\
\029\001\242\254\000\000\020\255\039\255\000\000\029\255\000\000\
\000\000\000\000\084\255\054\255\067\255\062\255\000\000\111\004\
\151\002\000\000\000\000\000\000\084\255\091\255\000\000\182\001\
\007\001\117\004\000\000\254\255\007\001\000\000\000\000\201\000\
\065\255\016\255\098\255\000\000\000\000\000\000\000\000\162\007\
\188\007\188\007\166\002\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\087\255\000\000\199\007\000\000\134\000\
\011\000\173\000\251\254\175\000\111\255\114\255\108\255\196\255\
\250\254\000\000\168\255\203\001\000\000\000\000\000\000\199\007\
\179\255\194\255\201\255\221\255\215\255\248\255\054\007\000\000\
\000\000\141\255\006\000\000\000\215\003\000\000\228\255\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\220\004\117\001\
\064\000\199\007\000\000\029\255\132\000\000\000\070\000\000\000\
\000\000\111\004\000\000\000\000\182\001\182\001\000\000\000\000\
\000\000\000\000\199\007\090\000\205\255\000\000\170\004\088\003\
\195\005\000\000\016\000\000\000\071\255\000\000\200\000\000\000\
\025\004\166\002\000\000\199\007\000\000\000\000\063\255\075\000\
\174\255\221\255\000\000\000\000\065\007\199\007\221\255\000\000\
\199\007\199\007\199\007\199\007\199\007\199\007\199\007\199\007\
\199\007\199\007\199\007\199\007\199\007\199\007\199\007\199\007\
\199\007\199\007\199\007\000\000\072\005\000\000\093\000\072\005\
\199\007\199\007\156\000\000\000\000\000\000\000\213\255\000\000\
\199\007\072\005\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\199\007\179\000\072\005\
\183\000\000\000\000\000\000\000\043\005\000\000\000\000\000\000\
\000\000\031\255\000\000\151\000\000\000\000\000\000\000\199\007\
\000\000\254\255\000\000\000\000\154\000\192\000\000\000\196\000\
\071\255\045\004\076\007\000\000\000\000\000\000\211\000\000\000\
\199\007\223\003\009\000\000\000\000\000\000\000\120\255\000\000\
\212\254\000\000\000\000\000\000\000\000\134\000\134\000\011\000\
\011\000\173\000\173\000\173\000\173\000\251\254\251\254\175\000\
\111\255\114\255\108\255\196\255\155\000\072\005\000\000\178\255\
\247\255\000\000\000\000\000\000\000\000\000\000\199\007\227\000\
\027\002\000\000\000\000\229\000\013\000\000\000\000\000\221\003\
\000\000\000\000\000\000\000\000\000\000\000\000\245\000\000\000\
\011\001\000\000\000\000\199\007\000\000\000\000\199\007\000\000\
\072\005\072\005\020\000\010\001\027\002\113\007\031\255\015\001\
\000\000\000\000\000\000\000\000\000\000\000\000\032\001\000\000\
\072\005\199\007\151\007\000\000\045\000\000\000\000\000\072\005\
\000\000\050\000\072\005\053\000\000\000\000\000\024\001\000\000\
\072\005\000\000\000\000"

let yyrindex = "\000\000\
\000\000\000\000\000\000\000\000\000\000\194\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\126\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\141\000\142\255\071\002\000\000\033\001\000\000\
\000\000\000\000\000\000\011\002\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\224\002\000\000\000\000\000\000\131\001\
\000\000\000\000\000\000\037\001\000\000\171\255\000\000\000\000\
\186\255\000\000\039\003\005\000\000\000\000\000\000\000\000\000\
\035\001\000\000\028\003\081\002\000\000\000\000\000\000\000\000\
\188\000\037\001\000\000\190\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\038\001\000\000\000\000\
\046\001\000\000\000\000\000\000\000\000\188\255\000\000\149\255\
\013\003\000\000\000\000\000\000\000\000\000\000\000\000\056\000\
\000\000\000\000\026\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\166\005\000\000\000\000\000\000\010\006\
\185\006\227\007\129\008\218\008\002\005\146\006\254\001\080\009\
\212\002\000\000\000\000\188\000\000\000\000\000\142\005\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\241\005\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\188\000\188\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\180\000\104\001\000\000\000\000\
\000\000\000\000\000\000\051\000\000\000\000\000\000\000\000\000\
\000\000\000\000\058\000\000\000\068\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\043\001\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\188\000\000\000\000\000\188\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\188\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\188\000\
\000\000\000\000\000\000\000\000\188\000\000\000\000\000\000\000\
\000\000\078\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\081\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\044\001\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\085\006\110\006\210\006\
\029\007\008\008\044\008\069\008\104\008\162\008\187\008\243\008\
\018\009\043\009\072\009\098\009\000\000\188\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\088\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\188\000\188\000\000\000\000\000\000\000\000\000\078\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\191\004\000\000\
\188\000\000\000\000\000\000\000\000\000\000\000\000\000\188\000\
\000\000\000\000\188\000\000\000\000\000\000\000\000\000\000\000\
\188\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\000\000\000\000\152\255\000\000\240\000\255\255\017\000\
\198\255\000\000\157\255\157\001\228\000\036\001\186\000\041\001\
\133\001\144\001\132\001\145\001\146\001\000\000\199\255\000\000\
\109\255\012\000\014\000\224\255\049\002\002\000\127\000\087\001\
\085\001\083\000\042\002\024\000\093\255\000\000\000\000\000\000\
\025\002\158\255\160\255\000\000\124\001\101\001\050\002\214\001\
\010\000\214\255\183\255\000\000\000\000\000\000\000\000\187\001\
\151\255\059\255\000\000\140\000\000\000\084\001\179\254\000\000\
\000\000\000\000\000\000\221\001\021\000\111\002\000\000\140\002\
\000\000\051\002\000\000\025\001"

let yytablesize = 2803
let yytable = "\032\000\
\076\000\032\000\028\000\113\000\247\000\041\001\204\000\194\000\
\192\000\232\000\233\000\117\001\033\000\242\000\034\000\082\000\
\048\000\079\000\215\000\133\000\146\000\001\001\027\001\052\000\
\032\000\001\000\217\000\110\001\005\000\032\000\023\001\050\000\
\032\000\084\000\224\000\005\000\055\000\065\000\050\000\131\001\
\075\000\032\000\033\000\077\000\034\000\078\000\032\000\031\001\
\064\000\053\000\069\000\091\000\005\000\040\001\255\000\050\000\
\005\000\062\000\088\000\050\000\057\000\211\000\213\000\214\000\
\005\000\090\000\065\000\050\000\082\000\065\000\032\000\062\000\
\092\000\087\000\091\001\133\000\234\000\235\000\109\000\243\000\
\099\000\207\000\097\000\101\000\103\000\208\000\059\000\178\000\
\005\000\032\000\112\000\050\000\026\000\133\000\146\000\102\000\
\218\000\219\000\220\000\032\000\194\000\176\000\027\000\179\000\
\180\000\215\000\032\000\215\000\103\000\041\001\032\000\052\001\
\187\000\217\000\102\000\051\000\026\000\057\001\068\000\133\000\
\146\000\203\000\183\000\074\000\102\000\059\001\060\001\061\001\
\001\001\184\000\159\000\196\000\048\001\159\000\206\000\202\000\
\133\000\146\000\077\001\042\001\097\001\043\001\133\000\146\000\
\080\001\081\001\083\000\068\000\092\000\083\000\068\000\105\001\
\026\000\126\000\251\000\221\000\126\000\222\000\096\000\223\000\
\076\000\101\000\027\000\209\000\020\000\021\000\133\000\133\000\
\133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
\133\000\133\000\133\000\133\000\133\000\133\000\133\000\133\000\
\238\000\108\001\190\000\103\000\122\001\109\001\087\000\159\000\
\240\000\087\000\159\000\159\000\159\000\239\000\032\000\027\000\
\104\000\032\000\187\000\000\001\083\000\107\001\001\001\083\000\
\029\000\203\000\083\000\083\000\083\000\112\000\241\000\126\000\
\053\001\126\000\126\000\126\000\083\000\058\001\112\000\053\000\
\103\001\005\000\051\001\126\000\050\000\133\000\146\000\104\000\
\104\000\095\000\234\000\104\000\095\000\056\001\115\001\244\000\
\133\000\146\000\050\001\001\001\201\000\248\000\133\000\113\001\
\087\000\104\000\095\000\087\000\027\000\095\000\087\000\087\000\
\087\000\095\000\005\000\003\000\004\000\050\000\249\000\005\000\
\087\000\089\000\006\000\033\001\089\000\250\000\034\001\190\000\
\190\000\084\001\095\000\083\001\005\000\252\000\001\001\050\000\
\092\001\138\001\140\001\015\001\016\001\017\001\086\001\246\000\
\032\000\007\000\008\000\009\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\025\000\133\000\126\001\253\000\112\000\
\001\001\196\000\019\001\051\001\114\001\003\000\004\000\112\000\
\195\000\005\000\026\000\089\000\006\000\104\000\089\000\026\000\
\002\001\089\000\089\000\089\000\027\000\050\001\119\001\201\000\
\104\000\027\000\120\001\089\000\200\000\001\001\201\000\228\000\
\229\000\129\001\029\000\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\108\001\054\000\
\187\000\135\000\141\001\001\001\135\000\092\001\001\001\143\001\
\067\000\171\000\145\001\176\000\125\001\171\000\022\001\176\000\
\246\000\026\000\080\000\079\001\083\000\177\000\056\001\070\000\
\004\000\177\000\026\001\027\000\089\000\085\001\063\000\244\000\
\049\001\081\000\178\000\244\000\029\000\067\000\178\000\098\000\
\067\000\245\000\100\000\088\001\032\001\245\000\105\000\078\001\
\019\001\066\001\067\001\068\001\069\001\007\000\008\000\009\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\132\000\230\000\231\000\132\000\189\000\105\000\105\000\236\000\
\237\000\105\000\116\000\116\000\025\001\180\000\103\000\062\001\
\063\001\103\000\096\000\081\000\044\001\005\000\081\000\105\000\
\050\000\081\000\081\000\081\000\225\000\226\000\227\000\095\001\
\096\001\112\001\082\001\081\000\001\001\111\001\029\000\099\001\
\103\000\103\000\103\000\103\000\103\000\103\000\103\000\103\000\
\103\000\103\000\103\000\103\000\103\000\103\000\103\000\103\000\
\103\000\103\000\103\000\158\000\158\000\158\000\132\000\087\001\
\132\000\132\000\132\000\089\001\127\001\128\001\143\000\143\000\
\103\000\116\000\132\000\103\000\116\000\100\001\103\000\103\000\
\103\000\064\001\065\001\101\001\137\001\200\000\063\000\201\000\
\103\000\189\000\189\000\142\001\070\001\071\001\144\001\027\000\
\106\001\103\000\116\001\105\000\147\001\148\000\004\000\149\000\
\150\000\151\000\118\000\119\000\006\000\120\000\105\000\121\000\
\122\000\118\001\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\029\001\030\001\123\001\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\130\001\152\000\
\153\000\154\000\124\001\155\000\135\001\136\001\146\001\156\000\
\157\000\158\000\159\000\160\000\079\000\161\000\029\000\165\000\
\236\000\123\000\235\000\237\000\238\000\133\001\125\000\126\000\
\127\000\128\000\129\000\130\000\130\000\233\000\047\001\130\000\
\174\000\176\000\072\001\074\001\029\000\148\000\004\000\149\000\
\150\000\151\000\118\000\119\000\006\000\120\000\073\001\121\000\
\122\000\075\001\177\000\076\001\182\000\199\000\098\001\160\000\
\181\000\024\001\160\000\046\001\021\001\058\000\049\000\134\001\
\185\000\000\000\000\000\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\000\000\152\000\
\153\000\154\000\130\000\155\000\130\000\130\000\130\000\156\000\
\157\000\158\000\159\000\160\000\079\000\020\001\130\000\000\000\
\000\000\123\000\000\000\000\000\000\000\000\000\125\000\126\000\
\127\000\128\000\129\000\130\000\160\000\000\000\000\000\160\000\
\160\000\160\000\000\000\245\000\029\000\149\000\150\000\151\000\
\118\000\119\000\006\000\120\000\000\000\121\000\122\000\000\000\
\000\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\025\000\000\000\
\000\000\007\000\008\000\009\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\025\000\000\000\152\000\153\000\154\000\
\000\000\155\000\000\000\000\000\000\000\156\000\157\000\158\000\
\159\000\160\000\079\000\149\000\149\000\029\000\000\000\123\000\
\055\000\055\000\149\000\000\000\125\000\126\000\127\000\128\000\
\129\000\130\000\000\000\000\000\000\000\149\000\000\000\117\000\
\118\000\119\000\029\000\120\000\000\000\121\000\122\000\000\000\
\000\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
\149\000\149\000\149\000\149\000\149\000\149\000\149\000\149\000\
\149\000\149\000\149\000\149\000\055\000\000\000\055\000\055\000\
\055\000\000\000\000\000\055\000\000\000\055\000\000\000\000\000\
\000\000\149\000\149\000\085\000\149\000\149\000\149\000\000\000\
\149\000\148\000\148\000\055\000\055\000\000\000\000\000\000\000\
\148\000\160\000\000\000\000\000\000\000\000\000\000\000\123\000\
\000\000\149\000\149\000\000\000\125\000\126\000\127\000\128\000\
\129\000\130\000\000\000\000\000\000\000\000\000\000\000\148\000\
\148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
\148\000\148\000\148\000\148\000\148\000\148\000\148\000\148\000\
\148\000\148\000\000\000\000\000\000\000\085\000\000\000\000\000\
\085\000\000\000\000\000\085\000\085\000\085\000\000\000\148\000\
\148\000\000\000\148\000\148\000\148\000\085\000\148\000\070\000\
\004\000\117\000\118\000\119\000\000\000\120\000\063\000\121\000\
\122\000\000\000\000\000\000\000\000\000\000\000\000\000\148\000\
\148\000\000\000\117\000\118\000\119\000\063\000\120\000\000\000\
\121\000\122\000\000\000\000\000\000\000\007\000\008\000\009\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\000\000\012\000\013\000\014\000\015\000\016\000\017\000\018\000\
\019\000\020\000\021\000\022\000\023\000\024\000\025\000\000\000\
\000\000\123\000\000\000\000\000\124\000\000\000\125\000\126\000\
\127\000\128\000\129\000\130\000\140\000\000\000\000\000\140\000\
\000\000\000\000\123\000\000\000\000\000\000\000\029\000\125\000\
\126\000\127\000\128\000\129\000\130\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\029\000\140\000\140\000\
\140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
\140\000\140\000\140\000\140\000\140\000\140\000\140\000\140\000\
\140\000\128\000\059\000\000\000\059\000\059\000\059\000\000\000\
\000\000\059\000\000\000\059\000\000\000\000\000\140\000\000\000\
\119\000\140\000\140\000\119\000\140\000\140\000\140\000\000\000\
\000\000\000\000\059\000\091\000\000\000\000\000\140\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\140\000\
\000\000\000\000\119\000\119\000\119\000\119\000\119\000\119\000\
\119\000\119\000\119\000\119\000\119\000\119\000\119\000\119\000\
\119\000\119\000\119\000\119\000\119\000\000\000\000\000\128\000\
\000\000\128\000\128\000\128\000\000\000\000\000\000\000\000\000\
\000\000\000\000\119\000\128\000\005\000\119\000\119\000\006\000\
\119\000\119\000\119\000\000\000\000\000\091\000\000\000\000\000\
\091\000\000\000\119\000\091\000\091\000\091\000\000\000\000\000\
\000\000\000\000\000\000\119\000\000\000\091\000\007\000\008\000\
\009\000\010\000\011\000\012\000\013\000\014\000\015\000\016\000\
\017\000\018\000\019\000\020\000\021\000\022\000\023\000\024\000\
\025\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\005\000\000\000\
\000\000\006\000\000\000\000\000\200\000\036\001\201\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\027\000\000\000\
\000\000\110\000\000\000\000\000\063\000\000\000\000\000\029\000\
\007\000\008\000\009\000\010\000\011\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\026\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\027\000\117\000\118\000\119\000\000\000\120\000\063\000\121\000\
\122\000\029\000\111\000\003\001\004\001\005\001\006\001\007\001\
\008\001\009\001\010\001\011\001\012\001\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\029\000\007\000\008\000\009\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\013\001\000\000\186\000\121\001\000\000\000\000\
\063\000\123\000\000\000\050\001\036\001\201\000\125\000\126\000\
\127\000\128\000\129\000\130\000\000\000\027\000\000\000\000\000\
\000\000\000\000\000\000\000\000\063\000\000\000\029\000\007\000\
\008\000\009\000\010\000\011\000\012\000\013\000\014\000\015\000\
\016\000\017\000\018\000\019\000\020\000\021\000\022\000\023\000\
\024\000\025\000\045\001\007\000\008\000\009\000\010\000\011\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\063\000\000\000\
\029\000\000\000\102\001\117\000\118\000\119\000\000\000\120\000\
\000\000\121\000\122\000\000\000\063\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\029\000\007\000\008\000\009\000\
\010\000\011\000\012\000\013\000\014\000\015\000\016\000\017\000\
\018\000\019\000\020\000\021\000\022\000\023\000\024\000\025\000\
\012\000\013\000\014\000\015\000\016\000\017\000\018\000\019\000\
\020\000\021\000\022\000\023\000\024\000\025\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\186\000\000\000\
\000\000\063\000\000\000\123\000\000\000\193\000\000\000\000\000\
\125\000\126\000\127\000\128\000\129\000\130\000\029\000\215\000\
\000\000\215\000\215\000\215\000\215\000\215\000\215\000\215\000\
\000\000\215\000\215\000\000\000\029\000\012\000\013\000\014\000\
\015\000\016\000\017\000\018\000\019\000\020\000\021\000\022\000\
\023\000\024\000\025\000\000\000\245\000\000\000\149\000\150\000\
\151\000\118\000\119\000\050\000\120\000\000\000\121\000\122\000\
\000\000\000\000\035\001\000\000\000\000\000\000\000\000\000\000\
\000\000\215\000\215\000\215\000\000\000\215\000\215\000\215\000\
\215\000\215\000\215\000\215\000\215\000\215\000\215\000\215\000\
\000\000\029\000\000\000\215\000\000\000\000\000\000\000\000\000\
\215\000\215\000\215\000\215\000\215\000\215\000\152\000\153\000\
\154\000\000\000\155\000\000\000\051\000\051\000\156\000\157\000\
\158\000\159\000\160\000\079\000\018\001\000\000\000\000\000\000\
\123\000\000\000\000\000\000\000\000\000\125\000\126\000\127\000\
\128\000\129\000\130\000\245\000\000\000\149\000\150\000\151\000\
\118\000\119\000\050\000\120\000\000\000\121\000\122\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\051\000\000\000\051\000\051\000\051\000\000\000\000\000\051\000\
\245\000\051\000\149\000\150\000\151\000\118\000\119\000\050\000\
\120\000\000\000\121\000\122\000\000\000\051\000\051\000\051\000\
\051\000\000\000\000\000\000\000\000\000\152\000\153\000\154\000\
\000\000\155\000\000\000\000\000\000\000\156\000\157\000\158\000\
\159\000\160\000\079\000\090\001\000\000\000\000\000\000\123\000\
\000\000\000\000\000\000\000\000\125\000\126\000\127\000\128\000\
\129\000\130\000\152\000\153\000\154\000\000\000\155\000\000\000\
\000\000\000\000\156\000\157\000\158\000\159\000\160\000\079\000\
\000\000\000\000\000\000\000\000\123\000\000\000\000\000\000\000\
\000\000\125\000\126\000\127\000\128\000\129\000\130\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\000\000\000\000\000\000\000\000\
\000\000\000\000\017\000\017\000\017\000\017\000\017\000\017\000\
\017\000\017\000\017\000\017\000\017\000\017\000\017\000\017\000\
\017\000\017\000\017\000\017\000\000\000\000\000\000\000\117\000\
\118\000\119\000\000\000\120\000\003\000\121\000\122\000\003\000\
\115\000\003\000\003\000\000\000\003\000\000\000\003\000\003\000\
\000\000\000\000\003\000\003\000\003\000\003\000\003\000\003\000\
\003\000\003\000\003\000\003\000\017\000\000\000\017\000\017\000\
\017\000\017\000\000\000\017\000\000\000\017\000\000\000\017\000\
\000\000\000\000\017\000\017\000\017\000\017\000\017\000\017\000\
\017\000\017\000\017\000\017\000\017\000\029\000\029\000\029\000\
\029\000\029\000\029\000\029\000\029\000\000\000\000\000\123\000\
\000\000\000\000\039\001\000\000\125\000\126\000\127\000\128\000\
\129\000\130\000\000\000\000\000\000\000\000\000\035\000\035\000\
\035\000\035\000\035\000\035\000\035\000\035\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\029\000\
\000\000\029\000\029\000\029\000\000\000\000\000\029\000\000\000\
\029\000\000\000\029\000\000\000\000\000\029\000\029\000\029\000\
\029\000\029\000\029\000\029\000\029\000\029\000\029\000\029\000\
\035\000\000\000\035\000\035\000\035\000\000\000\000\000\035\000\
\000\000\035\000\000\000\035\000\000\000\000\000\035\000\035\000\
\000\000\000\000\000\000\035\000\035\000\035\000\035\000\035\000\
\035\000\037\000\037\000\037\000\037\000\037\000\037\000\037\000\
\037\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\036\000\036\000\036\000\036\000\036\000\036\000\
\036\000\036\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\037\000\000\000\037\000\037\000\037\000\
\000\000\000\000\037\000\000\000\037\000\000\000\037\000\000\000\
\000\000\037\000\037\000\000\000\053\000\053\000\037\000\037\000\
\037\000\037\000\037\000\037\000\036\000\000\000\036\000\036\000\
\036\000\000\000\000\000\036\000\000\000\036\000\000\000\036\000\
\000\000\000\000\036\000\036\000\000\000\000\000\000\000\036\000\
\036\000\036\000\036\000\036\000\036\000\038\000\038\000\038\000\
\038\000\038\000\038\000\038\000\038\000\000\000\000\000\000\000\
\053\000\000\000\053\000\053\000\053\000\000\000\000\000\053\000\
\000\000\053\000\000\000\000\000\000\000\000\000\039\000\039\000\
\039\000\039\000\039\000\039\000\039\000\039\000\053\000\053\000\
\053\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\038\000\
\000\000\038\000\038\000\038\000\000\000\000\000\038\000\000\000\
\038\000\000\000\038\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\038\000\038\000\038\000\038\000\038\000\038\000\
\039\000\000\000\039\000\039\000\039\000\000\000\000\000\039\000\
\000\000\039\000\000\000\039\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\039\000\039\000\039\000\039\000\039\000\
\039\000\040\000\040\000\040\000\040\000\040\000\040\000\040\000\
\040\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\117\000\118\000\119\000\000\000\120\000\000\000\
\121\000\122\000\000\000\000\000\000\000\117\000\118\000\119\000\
\000\000\120\000\000\000\121\000\122\000\000\000\000\000\000\000\
\117\000\118\000\119\000\000\000\120\000\000\000\121\000\122\000\
\000\000\000\000\000\000\040\000\000\000\040\000\040\000\040\000\
\000\000\000\000\040\000\000\000\040\000\000\000\040\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\040\000\040\000\
\040\000\040\000\040\000\040\000\254\000\117\000\118\000\119\000\
\000\000\120\000\123\000\121\000\122\000\000\000\000\000\125\000\
\126\000\127\000\128\000\129\000\130\000\123\000\054\001\000\000\
\000\000\000\000\125\000\126\000\127\000\128\000\129\000\130\000\
\123\000\000\000\000\000\104\001\000\000\125\000\126\000\127\000\
\128\000\129\000\130\000\117\000\118\000\119\000\000\000\120\000\
\000\000\121\000\122\000\000\000\000\000\000\000\117\000\118\000\
\119\000\000\000\120\000\000\000\121\000\122\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\123\000\132\001\000\000\
\000\000\000\000\125\000\126\000\127\000\128\000\129\000\130\000\
\117\000\118\000\119\000\000\000\120\000\000\000\121\000\122\000\
\000\000\000\000\000\000\117\000\118\000\119\000\000\000\120\000\
\000\000\121\000\122\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\123\000\139\001\000\000\000\000\000\000\
\125\000\126\000\127\000\128\000\129\000\130\000\210\000\000\000\
\000\000\000\000\000\000\125\000\126\000\127\000\128\000\129\000\
\130\000\041\000\041\000\041\000\041\000\041\000\041\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\212\000\000\000\000\000\000\000\000\000\125\000\126\000\127\000\
\128\000\129\000\130\000\123\000\000\000\000\000\000\000\000\000\
\125\000\126\000\127\000\128\000\129\000\130\000\044\000\044\000\
\044\000\044\000\044\000\044\000\000\000\000\000\000\000\000\000\
\000\000\041\000\000\000\041\000\041\000\041\000\000\000\000\000\
\041\000\000\000\041\000\000\000\041\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\041\000\041\000\041\000\041\000\
\041\000\041\000\045\000\045\000\045\000\045\000\045\000\045\000\
\000\000\000\000\000\000\000\000\000\000\000\000\044\000\000\000\
\044\000\044\000\044\000\000\000\000\000\044\000\000\000\044\000\
\000\000\044\000\000\000\042\000\042\000\042\000\042\000\042\000\
\042\000\044\000\044\000\044\000\044\000\044\000\044\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\045\000\000\000\045\000\045\000\045\000\000\000\
\000\000\045\000\000\000\045\000\000\000\045\000\043\000\043\000\
\043\000\043\000\043\000\043\000\000\000\045\000\045\000\045\000\
\045\000\045\000\045\000\042\000\000\000\042\000\042\000\042\000\
\000\000\000\000\042\000\000\000\042\000\000\000\042\000\000\000\
\000\000\046\000\046\000\046\000\046\000\000\000\042\000\042\000\
\042\000\042\000\042\000\042\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\043\000\000\000\
\043\000\043\000\043\000\000\000\000\000\043\000\000\000\043\000\
\000\000\043\000\047\000\047\000\047\000\047\000\000\000\000\000\
\000\000\043\000\043\000\043\000\043\000\043\000\043\000\046\000\
\000\000\046\000\046\000\046\000\000\000\000\000\046\000\000\000\
\046\000\000\000\046\000\048\000\048\000\048\000\048\000\000\000\
\000\000\000\000\000\000\000\000\046\000\046\000\046\000\046\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\047\000\000\000\047\000\047\000\047\000\000\000\000\000\047\000\
\000\000\047\000\000\000\047\000\049\000\049\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\047\000\047\000\047\000\
\047\000\048\000\000\000\048\000\048\000\048\000\000\000\000\000\
\048\000\000\000\048\000\000\000\048\000\050\000\050\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\048\000\048\000\
\048\000\048\000\000\000\000\000\000\000\000\000\000\000\000\000\
\049\000\000\000\049\000\049\000\049\000\000\000\000\000\049\000\
\000\000\049\000\000\000\049\000\052\000\052\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\049\000\049\000\049\000\
\049\000\050\000\000\000\050\000\050\000\050\000\000\000\000\000\
\050\000\000\000\050\000\000\000\050\000\054\000\054\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\050\000\050\000\
\050\000\050\000\000\000\000\000\000\000\000\000\000\000\000\000\
\052\000\000\000\052\000\052\000\052\000\000\000\000\000\052\000\
\000\000\052\000\056\000\056\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\057\000\000\000\052\000\052\000\052\000\
\052\000\054\000\000\000\054\000\054\000\054\000\000\000\000\000\
\054\000\000\000\054\000\000\000\000\000\058\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\054\000\
\054\000\054\000\000\000\000\000\000\000\000\000\056\000\000\000\
\056\000\056\000\056\000\000\000\000\000\056\000\057\000\056\000\
\057\000\057\000\057\000\000\000\000\000\057\000\000\000\057\000\
\000\000\000\000\000\000\000\000\000\000\056\000\056\000\000\000\
\058\000\000\000\058\000\058\000\058\000\057\000\057\000\058\000\
\000\000\058\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\058\000\
\058\000\007\000\008\000\009\000\010\000\011\000\012\000\013\000\
\014\000\015\000\016\000\017\000\018\000\019\000\020\000\021\000\
\022\000\023\000\024\000\025\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\029\000"

let yycheck = "\001\000\
\043\000\003\000\000\000\077\000\152\000\203\000\112\000\106\000\
\105\000\015\001\016\001\089\001\001\000\020\001\001\000\048\000\
\003\000\064\001\123\000\078\000\078\000\066\001\186\000\025\000\
\026\000\001\000\123\000\072\001\005\001\031\000\178\000\008\001\
\034\000\005\001\134\000\005\001\027\000\036\000\008\001\117\001\
\042\000\043\000\031\000\069\001\031\000\071\001\048\000\195\000\
\035\000\026\000\037\000\066\001\005\001\201\000\159\000\008\001\
\005\001\034\000\070\001\008\001\000\000\120\000\121\000\122\000\
\005\001\056\000\065\000\008\001\101\000\068\000\072\000\048\000\
\087\001\064\001\044\001\134\000\082\001\083\001\064\001\086\001\
\067\000\066\001\062\000\070\000\073\000\070\001\063\001\068\001\
\005\001\091\000\077\000\008\001\069\001\152\000\152\000\072\000\
\010\001\011\001\012\001\101\000\199\000\081\000\079\001\065\001\
\066\001\210\000\108\000\212\000\097\000\051\001\112\000\217\000\
\096\000\210\000\091\000\064\001\069\001\222\000\036\000\178\000\
\178\000\112\000\069\001\064\001\101\000\225\000\226\000\227\000\
\066\001\063\001\005\001\108\000\070\001\008\001\070\001\112\000\
\195\000\195\000\243\000\069\001\032\001\071\001\201\000\201\000\
\249\000\250\000\005\001\065\000\087\001\008\001\068\000\043\001\
\069\001\005\001\156\000\069\001\008\001\071\001\068\001\073\001\
\203\000\148\000\079\001\066\001\044\001\045\001\225\000\226\000\
\227\000\228\000\229\000\230\000\231\000\232\000\233\000\234\000\
\235\000\236\000\237\000\238\000\239\000\240\000\241\000\242\000\
\074\001\066\001\104\000\176\000\096\001\070\001\005\001\066\001\
\085\001\008\001\069\001\070\001\071\001\084\001\200\000\079\001\
\074\000\203\000\186\000\063\001\063\001\049\001\066\001\066\001\
\088\001\200\000\069\001\070\001\071\001\200\000\019\001\067\001\
\218\000\069\001\070\001\071\001\079\001\223\000\209\000\200\000\
\042\001\005\001\217\000\079\001\008\001\032\001\032\001\105\000\
\106\000\063\001\064\001\109\000\066\001\221\000\087\001\072\001\
\043\001\043\001\069\001\066\001\071\001\067\001\049\001\070\001\
\063\001\123\000\063\001\066\001\079\001\066\001\069\001\070\001\
\071\001\087\001\005\001\001\001\002\001\008\001\069\001\005\001\
\079\001\005\001\008\001\063\001\008\001\069\001\066\001\189\000\
\190\000\001\001\087\001\063\001\005\001\063\001\066\001\008\001\
\026\001\130\001\131\001\056\001\057\001\058\001\014\001\148\000\
\034\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\111\001\111\001\063\001\042\001\
\066\001\034\001\175\000\050\001\070\001\001\001\002\001\050\001\
\067\001\005\001\069\001\063\001\008\001\199\000\066\001\069\001\
\067\001\069\001\070\001\071\001\079\001\069\001\066\001\071\001\
\210\000\079\001\070\001\079\001\069\001\066\001\071\001\077\001\
\078\001\070\001\088\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\066\001\027\000\
\096\001\063\001\070\001\066\001\066\001\119\001\066\001\070\001\
\036\000\066\001\070\001\066\001\108\001\070\001\063\001\070\001\
\245\000\069\001\047\000\248\000\049\000\066\001\118\001\001\001\
\002\001\070\001\069\001\079\001\056\000\002\001\008\001\066\001\
\070\001\005\001\066\001\070\001\088\001\065\000\070\001\065\000\
\068\000\066\001\068\000\016\001\067\001\070\001\074\000\067\001\
\021\001\232\000\233\000\234\000\235\000\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\005\001\013\001\014\001\008\001\104\000\105\000\106\000\017\001\
\018\001\109\000\001\001\002\001\065\001\066\001\005\001\228\000\
\229\000\008\001\068\001\063\001\005\001\005\001\066\001\123\000\
\008\001\069\001\070\001\071\001\079\001\080\001\081\001\065\001\
\066\001\078\001\063\001\079\001\066\001\067\001\088\001\070\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\056\001\057\001\058\001\067\001\069\001\
\069\001\070\001\071\001\069\001\113\001\114\001\065\001\066\001\
\063\001\064\001\079\001\066\001\067\001\070\001\069\001\070\001\
\071\001\230\000\231\000\072\001\129\001\069\001\008\001\071\001\
\079\001\189\000\190\000\136\001\236\000\237\000\139\001\079\001\
\070\001\088\001\056\001\199\000\145\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\210\000\011\001\
\012\001\069\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\189\000\190\000\070\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\069\001\051\001\
\052\001\053\001\072\001\055\001\070\001\054\001\063\001\059\001\
\060\001\061\001\062\001\063\001\064\001\065\001\088\001\070\001\
\064\001\069\001\064\001\063\001\063\001\118\001\074\001\075\001\
\076\001\077\001\078\001\079\001\005\001\064\001\210\000\008\001\
\070\001\070\001\238\000\240\000\088\001\001\001\002\001\003\001\
\004\001\005\001\006\001\007\001\008\001\009\001\239\000\011\001\
\012\001\241\000\082\000\242\000\091\000\109\000\034\001\005\001\
\087\000\180\000\008\001\209\000\176\000\031\000\003\000\119\001\
\094\000\255\255\255\255\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\255\255\051\001\
\052\001\053\001\067\001\055\001\069\001\070\001\071\001\059\001\
\060\001\061\001\062\001\063\001\064\001\065\001\079\001\255\255\
\255\255\069\001\255\255\255\255\255\255\255\255\074\001\075\001\
\076\001\077\001\078\001\079\001\066\001\255\255\255\255\069\001\
\070\001\071\001\255\255\001\001\088\001\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\255\255\011\001\012\001\255\255\
\255\255\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\255\255\
\255\255\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\255\255\051\001\052\001\053\001\
\255\255\055\001\255\255\255\255\255\255\059\001\060\001\061\001\
\062\001\063\001\064\001\001\001\002\001\088\001\255\255\069\001\
\019\001\020\001\008\001\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\255\255\255\255\003\001\255\255\005\001\
\006\001\007\001\088\001\009\001\255\255\011\001\012\001\255\255\
\255\255\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\063\001\255\255\065\001\066\001\
\067\001\255\255\255\255\070\001\255\255\072\001\255\255\255\255\
\255\255\063\001\064\001\005\001\066\001\067\001\068\001\255\255\
\070\001\001\001\002\001\086\001\087\001\255\255\255\255\255\255\
\008\001\063\001\255\255\255\255\255\255\255\255\255\255\069\001\
\255\255\087\001\088\001\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\255\255\255\255\255\255\255\255\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\255\255\255\255\255\255\063\001\255\255\255\255\
\066\001\255\255\255\255\069\001\070\001\071\001\255\255\063\001\
\064\001\255\255\066\001\067\001\068\001\079\001\070\001\001\001\
\002\001\005\001\006\001\007\001\255\255\009\001\008\001\011\001\
\012\001\255\255\255\255\255\255\255\255\255\255\255\255\087\001\
\088\001\255\255\005\001\006\001\007\001\008\001\009\001\255\255\
\011\001\012\001\255\255\255\255\255\255\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\255\255\036\001\037\001\038\001\039\001\040\001\041\001\042\001\
\043\001\044\001\045\001\046\001\047\001\048\001\049\001\255\255\
\255\255\069\001\255\255\255\255\072\001\255\255\074\001\075\001\
\076\001\077\001\078\001\079\001\005\001\255\255\255\255\008\001\
\255\255\255\255\069\001\255\255\255\255\255\255\088\001\074\001\
\075\001\076\001\077\001\078\001\079\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\088\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\005\001\063\001\255\255\065\001\066\001\067\001\255\255\
\255\255\070\001\255\255\072\001\255\255\255\255\063\001\255\255\
\005\001\066\001\067\001\008\001\069\001\070\001\071\001\255\255\
\255\255\255\255\087\001\005\001\255\255\255\255\079\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\088\001\
\255\255\255\255\031\001\032\001\033\001\034\001\035\001\036\001\
\037\001\038\001\039\001\040\001\041\001\042\001\043\001\044\001\
\045\001\046\001\047\001\048\001\049\001\255\255\255\255\067\001\
\255\255\069\001\070\001\071\001\255\255\255\255\255\255\255\255\
\255\255\255\255\063\001\079\001\005\001\066\001\067\001\008\001\
\069\001\070\001\071\001\255\255\255\255\063\001\255\255\255\255\
\066\001\255\255\079\001\069\001\070\001\071\001\255\255\255\255\
\255\255\255\255\255\255\088\001\255\255\079\001\031\001\032\001\
\033\001\034\001\035\001\036\001\037\001\038\001\039\001\040\001\
\041\001\042\001\043\001\044\001\045\001\046\001\047\001\048\001\
\049\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\005\001\255\255\
\255\255\008\001\255\255\255\255\069\001\070\001\071\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\079\001\255\255\
\255\255\005\001\255\255\255\255\008\001\255\255\255\255\088\001\
\031\001\032\001\033\001\034\001\035\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\069\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\079\001\005\001\006\001\007\001\255\255\009\001\008\001\011\001\
\012\001\088\001\070\001\021\001\022\001\023\001\024\001\025\001\
\026\001\027\001\028\001\029\001\030\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\088\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\068\001\255\255\064\001\065\001\255\255\255\255\
\008\001\069\001\255\255\069\001\070\001\071\001\074\001\075\001\
\076\001\077\001\078\001\079\001\255\255\079\001\255\255\255\255\
\255\255\255\255\255\255\255\255\008\001\255\255\088\001\031\001\
\032\001\033\001\034\001\035\001\036\001\037\001\038\001\039\001\
\040\001\041\001\042\001\043\001\044\001\045\001\046\001\047\001\
\048\001\049\001\050\001\031\001\032\001\033\001\034\001\035\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\008\001\255\255\
\088\001\255\255\070\001\005\001\006\001\007\001\255\255\009\001\
\255\255\011\001\012\001\255\255\008\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\088\001\031\001\032\001\033\001\
\034\001\035\001\036\001\037\001\038\001\039\001\040\001\041\001\
\042\001\043\001\044\001\045\001\046\001\047\001\048\001\049\001\
\036\001\037\001\038\001\039\001\040\001\041\001\042\001\043\001\
\044\001\045\001\046\001\047\001\048\001\049\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\064\001\255\255\
\255\255\008\001\255\255\069\001\255\255\065\001\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\088\001\001\001\
\255\255\003\001\004\001\005\001\006\001\007\001\008\001\009\001\
\255\255\011\001\012\001\255\255\088\001\036\001\037\001\038\001\
\039\001\040\001\041\001\042\001\043\001\044\001\045\001\046\001\
\047\001\048\001\049\001\255\255\001\001\255\255\003\001\004\001\
\005\001\006\001\007\001\008\001\009\001\255\255\011\001\012\001\
\255\255\255\255\065\001\255\255\255\255\255\255\255\255\255\255\
\255\255\051\001\052\001\053\001\255\255\055\001\056\001\057\001\
\058\001\059\001\060\001\061\001\062\001\063\001\064\001\065\001\
\255\255\088\001\255\255\069\001\255\255\255\255\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\051\001\052\001\
\053\001\255\255\055\001\255\255\019\001\020\001\059\001\060\001\
\061\001\062\001\063\001\064\001\065\001\255\255\255\255\255\255\
\069\001\255\255\255\255\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\001\001\255\255\003\001\004\001\005\001\
\006\001\007\001\008\001\009\001\255\255\011\001\012\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\001\001\072\001\003\001\004\001\005\001\006\001\007\001\008\001\
\009\001\255\255\011\001\012\001\255\255\084\001\085\001\086\001\
\087\001\255\255\255\255\255\255\255\255\051\001\052\001\053\001\
\255\255\055\001\255\255\255\255\255\255\059\001\060\001\061\001\
\062\001\063\001\064\001\065\001\255\255\255\255\255\255\069\001\
\255\255\255\255\255\255\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\051\001\052\001\053\001\255\255\055\001\255\255\
\255\255\255\255\059\001\060\001\061\001\062\001\063\001\064\001\
\255\255\255\255\255\255\255\255\069\001\255\255\255\255\255\255\
\255\255\074\001\075\001\076\001\077\001\078\001\079\001\010\001\
\011\001\012\001\013\001\014\001\015\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\255\255\
\255\255\255\255\013\001\014\001\015\001\016\001\017\001\018\001\
\019\001\020\001\021\001\022\001\023\001\024\001\025\001\026\001\
\027\001\028\001\029\001\030\001\255\255\255\255\255\255\005\001\
\006\001\007\001\255\255\009\001\063\001\011\001\012\001\066\001\
\067\001\068\001\069\001\255\255\071\001\255\255\073\001\074\001\
\255\255\255\255\077\001\078\001\079\001\080\001\081\001\082\001\
\083\001\084\001\085\001\086\001\063\001\255\255\065\001\066\001\
\067\001\068\001\255\255\070\001\255\255\072\001\255\255\074\001\
\255\255\255\255\077\001\078\001\079\001\080\001\081\001\082\001\
\083\001\084\001\085\001\086\001\087\001\013\001\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\255\255\255\255\069\001\
\255\255\255\255\072\001\255\255\074\001\075\001\076\001\077\001\
\078\001\079\001\255\255\255\255\255\255\255\255\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\063\001\
\255\255\065\001\066\001\067\001\255\255\255\255\070\001\255\255\
\072\001\255\255\074\001\255\255\255\255\077\001\078\001\079\001\
\080\001\081\001\082\001\083\001\084\001\085\001\086\001\087\001\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\255\255\072\001\255\255\074\001\255\255\255\255\077\001\078\001\
\255\255\255\255\255\255\082\001\083\001\084\001\085\001\086\001\
\087\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\013\001\014\001\015\001\016\001\017\001\018\001\
\019\001\020\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\063\001\255\255\065\001\066\001\067\001\
\255\255\255\255\070\001\255\255\072\001\255\255\074\001\255\255\
\255\255\077\001\078\001\255\255\019\001\020\001\082\001\083\001\
\084\001\085\001\086\001\087\001\063\001\255\255\065\001\066\001\
\067\001\255\255\255\255\070\001\255\255\072\001\255\255\074\001\
\255\255\255\255\077\001\078\001\255\255\255\255\255\255\082\001\
\083\001\084\001\085\001\086\001\087\001\013\001\014\001\015\001\
\016\001\017\001\018\001\019\001\020\001\255\255\255\255\255\255\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\255\255\072\001\255\255\255\255\255\255\255\255\013\001\014\001\
\015\001\016\001\017\001\018\001\019\001\020\001\085\001\086\001\
\087\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\063\001\
\255\255\065\001\066\001\067\001\255\255\255\255\070\001\255\255\
\072\001\255\255\074\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\082\001\083\001\084\001\085\001\086\001\087\001\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\255\255\072\001\255\255\074\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\082\001\083\001\084\001\085\001\086\001\
\087\001\013\001\014\001\015\001\016\001\017\001\018\001\019\001\
\020\001\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\005\001\006\001\007\001\255\255\009\001\255\255\
\011\001\012\001\255\255\255\255\255\255\005\001\006\001\007\001\
\255\255\009\001\255\255\011\001\012\001\255\255\255\255\255\255\
\005\001\006\001\007\001\255\255\009\001\255\255\011\001\012\001\
\255\255\255\255\255\255\063\001\255\255\065\001\066\001\067\001\
\255\255\255\255\070\001\255\255\072\001\255\255\074\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\082\001\083\001\
\084\001\085\001\086\001\087\001\063\001\005\001\006\001\007\001\
\255\255\009\001\069\001\011\001\012\001\255\255\255\255\074\001\
\075\001\076\001\077\001\078\001\079\001\069\001\070\001\255\255\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\069\001\255\255\255\255\072\001\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\005\001\006\001\007\001\255\255\009\001\
\255\255\011\001\012\001\255\255\255\255\255\255\005\001\006\001\
\007\001\255\255\009\001\255\255\011\001\012\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\069\001\070\001\255\255\
\255\255\255\255\074\001\075\001\076\001\077\001\078\001\079\001\
\005\001\006\001\007\001\255\255\009\001\255\255\011\001\012\001\
\255\255\255\255\255\255\005\001\006\001\007\001\255\255\009\001\
\255\255\011\001\012\001\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\069\001\070\001\255\255\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\069\001\255\255\
\255\255\255\255\255\255\074\001\075\001\076\001\077\001\078\001\
\079\001\015\001\016\001\017\001\018\001\019\001\020\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\069\001\255\255\255\255\255\255\255\255\074\001\075\001\076\001\
\077\001\078\001\079\001\069\001\255\255\255\255\255\255\255\255\
\074\001\075\001\076\001\077\001\078\001\079\001\015\001\016\001\
\017\001\018\001\019\001\020\001\255\255\255\255\255\255\255\255\
\255\255\063\001\255\255\065\001\066\001\067\001\255\255\255\255\
\070\001\255\255\072\001\255\255\074\001\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\082\001\083\001\084\001\085\001\
\086\001\087\001\015\001\016\001\017\001\018\001\019\001\020\001\
\255\255\255\255\255\255\255\255\255\255\255\255\063\001\255\255\
\065\001\066\001\067\001\255\255\255\255\070\001\255\255\072\001\
\255\255\074\001\255\255\015\001\016\001\017\001\018\001\019\001\
\020\001\082\001\083\001\084\001\085\001\086\001\087\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\063\001\255\255\065\001\066\001\067\001\255\255\
\255\255\070\001\255\255\072\001\255\255\074\001\015\001\016\001\
\017\001\018\001\019\001\020\001\255\255\082\001\083\001\084\001\
\085\001\086\001\087\001\063\001\255\255\065\001\066\001\067\001\
\255\255\255\255\070\001\255\255\072\001\255\255\074\001\255\255\
\255\255\017\001\018\001\019\001\020\001\255\255\082\001\083\001\
\084\001\085\001\086\001\087\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\063\001\255\255\
\065\001\066\001\067\001\255\255\255\255\070\001\255\255\072\001\
\255\255\074\001\017\001\018\001\019\001\020\001\255\255\255\255\
\255\255\082\001\083\001\084\001\085\001\086\001\087\001\063\001\
\255\255\065\001\066\001\067\001\255\255\255\255\070\001\255\255\
\072\001\255\255\074\001\017\001\018\001\019\001\020\001\255\255\
\255\255\255\255\255\255\255\255\084\001\085\001\086\001\087\001\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\255\255\072\001\255\255\074\001\019\001\020\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\084\001\085\001\086\001\
\087\001\063\001\255\255\065\001\066\001\067\001\255\255\255\255\
\070\001\255\255\072\001\255\255\074\001\019\001\020\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\084\001\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\255\255\072\001\255\255\074\001\019\001\020\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\084\001\085\001\086\001\
\087\001\063\001\255\255\065\001\066\001\067\001\255\255\255\255\
\070\001\255\255\072\001\255\255\074\001\019\001\020\001\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\084\001\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\255\255\255\255\
\063\001\255\255\065\001\066\001\067\001\255\255\255\255\070\001\
\255\255\072\001\019\001\020\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\020\001\255\255\084\001\085\001\086\001\
\087\001\063\001\255\255\065\001\066\001\067\001\255\255\255\255\
\070\001\255\255\072\001\255\255\255\255\020\001\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\085\001\
\086\001\087\001\255\255\255\255\255\255\255\255\063\001\255\255\
\065\001\066\001\067\001\255\255\255\255\070\001\063\001\072\001\
\065\001\066\001\067\001\255\255\255\255\070\001\255\255\072\001\
\255\255\255\255\255\255\255\255\255\255\086\001\087\001\255\255\
\063\001\255\255\065\001\066\001\067\001\086\001\087\001\070\001\
\255\255\072\001\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\086\001\
\087\001\031\001\032\001\033\001\034\001\035\001\036\001\037\001\
\038\001\039\001\040\001\041\001\042\001\043\001\044\001\045\001\
\046\001\047\001\048\001\049\001\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\088\001"

let yynames_const = "\
  SIZEOF\000\
  PTR_OP\000\
  INC_OP\000\
  DEC_OP\000\
  LEFT_OP\000\
  RIGHT_OP\000\
  LE_OP\000\
  GE_OP\000\
  EQ_OP\000\
  NE_OP\000\
  AND_OP\000\
  OR_OP\000\
  MUL_ASSIGN\000\
  DIV_ASSIGN\000\
  MOD_ASSIGN\000\
  ADD_ASSIGN\000\
  SUB_ASSIGN\000\
  LEFT_ASSIGN\000\
  RIGHT_ASSIGN\000\
  AND_ASSIGN\000\
  XOR_ASSIGN\000\
  OR_ASSIGN\000\
  TYPEDEF\000\
  EXTERN\000\
  STATIC\000\
  AUTO\000\
  REGISTER\000\
  CHAR\000\
  SHORT\000\
  INT\000\
  LONG\000\
  SIGNED\000\
  UNSIGNED\000\
  FLOAT\000\
  DOUBLE\000\
  CONST\000\
  VOLATILE\000\
  VOID\000\
  STRUCT\000\
  UNION\000\
  ENUM\000\
  ELLIPSIS\000\
  CASE\000\
  DEFAULT\000\
  IF\000\
  ELSE\000\
  SWITCH\000\
  WHILE\000\
  DO\000\
  FOR\000\
  GOTO\000\
  CONTINUE\000\
  BREAK\000\
  RETURN\000\
  SEMICOLON\000\
  LBRACE\000\
  RBRACE\000\
  COMMA\000\
  COLON\000\
  EQUAL\000\
  LPAR\000\
  RPAR\000\
  LSQUARE\000\
  RSQUARE\000\
  DOT\000\
  AMP\000\
  EXL\000\
  TILDE\000\
  MINUS\000\
  PLUS\000\
  STAR\000\
  SLASH\000\
  PERCENT\000\
  LT\000\
  GT\000\
  HAT\000\
  PIPE\000\
  QUESTION\000\
  EOF\000\
  ATTRIBUTE\000\
  RESTRICT\000\
  "

let yynames_block = "\
  SPEC\000\
  DECL\000\
  CODE_ANNOT\000\
  LOOP_ANNOT\000\
  IDENTIFIER\000\
  CONSTANT\000\
  STRING_LITERAL\000\
  TYPE_NAME\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'translation_unit) in
    Obj.repr(
# 328 "c/cparser.mly"
                               ( _1 )
# 1522 "c/cparser.ml"
               : Cast.file))
; (fun parser_env ->
    Obj.repr(
# 329 "c/cparser.mly"
              ( [] )
# 1528 "c/cparser.ml"
               : Cast.file))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 333 "c/cparser.mly"
                     ( locate (CEvar _1) )
# 1535 "c/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 334 "c/cparser.mly"
                   ( locate (CEconstant _1) )
# 1542 "c/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 335 "c/cparser.mly"
                         ( locate (CEstring_literal _1) )
# 1549 "c/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'expression) in
    Obj.repr(
# 336 "c/cparser.mly"
                               ( _2 )
# 1556 "c/cparser.ml"
               : 'primary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'primary_expression) in
    Obj.repr(
# 341 "c/cparser.mly"
            ( _1 )
# 1563 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'postfix_expression) in
    let _3 = (peek_val parser_env 1 : 'expression) in
    Obj.repr(
# 343 "c/cparser.mly"
     ( locate (CEarrget (_1, _3)) )
# 1571 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_expression) in
    Obj.repr(
# 345 "c/cparser.mly"
     ( locate (CEcall (_1, [])) )
# 1578 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'postfix_expression) in
    let _3 = (peek_val parser_env 1 : 'argument_expression_list) in
    Obj.repr(
# 347 "c/cparser.mly"
     ( locate (CEcall (_1, _3)) )
# 1586 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_expression) in
    let _3 = (peek_val parser_env 0 : 'identifier) in
    Obj.repr(
# 349 "c/cparser.mly"
     ( locate (CEdot (_1, _3)) )
# 1594 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'postfix_expression) in
    let _3 = (peek_val parser_env 0 : 'identifier) in
    Obj.repr(
# 351 "c/cparser.mly"
     ( locate (CEarrow (_1, _3)) )
# 1602 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'postfix_expression) in
    Obj.repr(
# 353 "c/cparser.mly"
     ( locate (CEincr (Upostfix_inc, _1)) )
# 1609 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'postfix_expression) in
    Obj.repr(
# 355 "c/cparser.mly"
     ( locate (CEincr (Upostfix_dec, _1)) )
# 1616 "c/cparser.ml"
               : 'postfix_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 359 "c/cparser.mly"
                                ( [_1] )
# 1623 "c/cparser.ml"
               : 'argument_expression_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'argument_expression_list) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 360 "c/cparser.mly"
                                                               ( _1 @ [_3] )
# 1631 "c/cparser.ml"
               : 'argument_expression_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'postfix_expression) in
    Obj.repr(
# 364 "c/cparser.mly"
                             ( _1 )
# 1638 "c/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 365 "c/cparser.mly"
                                  ( locate (CEincr (Uprefix_inc, _2)) )
# 1645 "c/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 366 "c/cparser.mly"
                                  ( locate (CEincr (Uprefix_dec, _2)) )
# 1652 "c/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'unary_operator) in
    let _2 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 367 "c/cparser.mly"
                                         ( locate (CEunary (_1, _2)) )
# 1660 "c/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 368 "c/cparser.mly"
                                  ( locate (CEsizeof_expr _2) )
# 1667 "c/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'type_name) in
    Obj.repr(
# 370 "c/cparser.mly"
     ( let s,d = _3 in locate (CEsizeof (interp_type false s d)) )
# 1674 "c/cparser.ml"
               : 'unary_expression))
; (fun parser_env ->
    Obj.repr(
# 374 "c/cparser.mly"
              ( Uamp )
# 1680 "c/cparser.ml"
               : 'unary_operator))
; (fun parser_env ->
    Obj.repr(
# 375 "c/cparser.mly"
               ( Ustar )
# 1686 "c/cparser.ml"
               : 'unary_operator))
; (fun parser_env ->
    Obj.repr(
# 376 "c/cparser.mly"
               ( Uplus )
# 1692 "c/cparser.ml"
               : 'unary_operator))
; (fun parser_env ->
    Obj.repr(
# 377 "c/cparser.mly"
                ( Uminus )
# 1698 "c/cparser.ml"
               : 'unary_operator))
; (fun parser_env ->
    Obj.repr(
# 378 "c/cparser.mly"
                ( Utilde )
# 1704 "c/cparser.ml"
               : 'unary_operator))
; (fun parser_env ->
    Obj.repr(
# 379 "c/cparser.mly"
              ( Unot )
# 1710 "c/cparser.ml"
               : 'unary_operator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'unary_expression) in
    Obj.repr(
# 383 "c/cparser.mly"
                           ( _1 )
# 1717 "c/cparser.ml"
               : 'cast_expression))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'type_name) in
    let _4 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 385 "c/cparser.mly"
     ( let s,d = _2 in locate (CEcast (interp_type false s d, _4)) )
# 1725 "c/cparser.ml"
               : 'cast_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 390 "c/cparser.mly"
            ( _1 )
# 1732 "c/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_expression) in
    let _3 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 392 "c/cparser.mly"
     ( locate (CEbinary (_1, Bmul, _3)) )
# 1740 "c/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_expression) in
    let _3 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 394 "c/cparser.mly"
     ( locate (CEbinary (_1, Bdiv, _3)) )
# 1748 "c/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'multiplicative_expression) in
    let _3 = (peek_val parser_env 0 : 'cast_expression) in
    Obj.repr(
# 396 "c/cparser.mly"
     ( locate (CEbinary (_1, Bmod, _3)) )
# 1756 "c/cparser.ml"
               : 'multiplicative_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 401 "c/cparser.mly"
           ( _1 )
# 1763 "c/cparser.ml"
               : 'additive_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'additive_expression) in
    let _3 = (peek_val parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 403 "c/cparser.mly"
     ( locate (CEbinary (_1, Badd, _3)) )
# 1771 "c/cparser.ml"
               : 'additive_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'additive_expression) in
    let _3 = (peek_val parser_env 0 : 'multiplicative_expression) in
    Obj.repr(
# 405 "c/cparser.mly"
     ( locate (CEbinary (_1, Bsub, _3)) )
# 1779 "c/cparser.ml"
               : 'additive_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'additive_expression) in
    Obj.repr(
# 409 "c/cparser.mly"
                              ( _1 )
# 1786 "c/cparser.ml"
               : 'shift_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'shift_expression) in
    let _3 = (peek_val parser_env 0 : 'additive_expression) in
    Obj.repr(
# 411 "c/cparser.mly"
     ( locate (CEbinary (_1, Bshift_left, _3)) )
# 1794 "c/cparser.ml"
               : 'shift_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'shift_expression) in
    let _3 = (peek_val parser_env 0 : 'additive_expression) in
    Obj.repr(
# 413 "c/cparser.mly"
     ( locate (CEbinary (_1, Bshift_right, _3)) )
# 1802 "c/cparser.ml"
               : 'shift_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 418 "c/cparser.mly"
            ( _1 )
# 1809 "c/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 420 "c/cparser.mly"
     ( locate (CEbinary (_1, Blt, _3)) )
# 1817 "c/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 422 "c/cparser.mly"
     ( locate (CEbinary (_1, Bgt, _3)) )
# 1825 "c/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 424 "c/cparser.mly"
     ( locate (CEbinary (_1, Ble, _3)) )
# 1833 "c/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'relational_expression) in
    let _3 = (peek_val parser_env 0 : 'shift_expression) in
    Obj.repr(
# 426 "c/cparser.mly"
     ( locate (CEbinary (_1, Bge, _3)) )
# 1841 "c/cparser.ml"
               : 'relational_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'relational_expression) in
    Obj.repr(
# 431 "c/cparser.mly"
            ( _1 )
# 1848 "c/cparser.ml"
               : 'equality_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'equality_expression) in
    let _3 = (peek_val parser_env 0 : 'relational_expression) in
    Obj.repr(
# 433 "c/cparser.mly"
     ( locate (CEbinary (_1, Beq, _3)) )
# 1856 "c/cparser.ml"
               : 'equality_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'equality_expression) in
    let _3 = (peek_val parser_env 0 : 'relational_expression) in
    Obj.repr(
# 435 "c/cparser.mly"
     ( locate (CEbinary (_1, Bneq, _3)) )
# 1864 "c/cparser.ml"
               : 'equality_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'equality_expression) in
    Obj.repr(
# 440 "c/cparser.mly"
            ( _1 )
# 1871 "c/cparser.ml"
               : 'and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'and_expression) in
    let _3 = (peek_val parser_env 0 : 'equality_expression) in
    Obj.repr(
# 442 "c/cparser.mly"
     ( locate (CEbinary (_1, Bbw_and, _3)) )
# 1879 "c/cparser.ml"
               : 'and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'and_expression) in
    Obj.repr(
# 447 "c/cparser.mly"
            ( _1 )
# 1886 "c/cparser.ml"
               : 'exclusive_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'exclusive_or_expression) in
    let _3 = (peek_val parser_env 0 : 'and_expression) in
    Obj.repr(
# 449 "c/cparser.mly"
     ( locate (CEbinary (_1, Bbw_xor, _3)) )
# 1894 "c/cparser.ml"
               : 'exclusive_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'exclusive_or_expression) in
    Obj.repr(
# 454 "c/cparser.mly"
            ( _1 )
# 1901 "c/cparser.ml"
               : 'inclusive_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'inclusive_or_expression) in
    let _3 = (peek_val parser_env 0 : 'exclusive_or_expression) in
    Obj.repr(
# 456 "c/cparser.mly"
     ( locate (CEbinary (_1, Bbw_or, _3)) )
# 1909 "c/cparser.ml"
               : 'inclusive_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'inclusive_or_expression) in
    Obj.repr(
# 461 "c/cparser.mly"
            ( _1 )
# 1916 "c/cparser.ml"
               : 'logical_and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'logical_and_expression) in
    let _3 = (peek_val parser_env 0 : 'inclusive_or_expression) in
    Obj.repr(
# 463 "c/cparser.mly"
     ( locate (CEbinary (_1, Band, _3)) )
# 1924 "c/cparser.ml"
               : 'logical_and_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 468 "c/cparser.mly"
            ( _1 )
# 1931 "c/cparser.ml"
               : 'logical_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'logical_or_expression) in
    let _3 = (peek_val parser_env 0 : 'logical_and_expression) in
    Obj.repr(
# 470 "c/cparser.mly"
     ( locate (CEbinary (_1, Bor, _3)) )
# 1939 "c/cparser.ml"
               : 'logical_or_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'logical_or_expression) in
    Obj.repr(
# 475 "c/cparser.mly"
            ( _1 )
# 1946 "c/cparser.ml"
               : 'conditional_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'logical_or_expression) in
    let _3 = (peek_val parser_env 2 : 'expression) in
    let _5 = (peek_val parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 477 "c/cparser.mly"
     ( locate (CEcond (_1, _3, _5)) )
# 1955 "c/cparser.ml"
               : 'conditional_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 482 "c/cparser.mly"
            ( _1 )
# 1962 "c/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'unary_expression) in
    let _2 = (peek_val parser_env 1 : 'assignment_operator) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 484 "c/cparser.mly"
     ( locate (match _2 with
			| Aequal -> CEassign (_1, _3)
			| Amul -> CEassign_op (_1, Bmul, _3)
			| Adiv -> CEassign_op (_1, Bdiv, _3)
			| Amod -> CEassign_op (_1, Bmod, _3)
			| Aadd -> CEassign_op (_1, Badd, _3)
			| Asub -> CEassign_op (_1, Bsub, _3)
			| Aleft -> CEassign_op (_1, Bshift_left, _3)
			| Aright -> CEassign_op (_1, Bshift_right, _3)
			| Aand -> CEassign_op (_1, Bbw_and, _3)
			| Axor -> CEassign_op (_1, Bbw_xor, _3)
			| Aor -> CEassign_op (_1, Bbw_or, _3)) )
# 1982 "c/cparser.ml"
               : 'assignment_expression))
; (fun parser_env ->
    Obj.repr(
# 499 "c/cparser.mly"
                ( Aequal )
# 1988 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 500 "c/cparser.mly"
                     ( Amul )
# 1994 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 501 "c/cparser.mly"
                     ( Adiv )
# 2000 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 502 "c/cparser.mly"
                     ( Amod )
# 2006 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 503 "c/cparser.mly"
                     ( Aadd )
# 2012 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 504 "c/cparser.mly"
                     ( Asub )
# 2018 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 505 "c/cparser.mly"
                      ( Aleft )
# 2024 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 506 "c/cparser.mly"
                       ( Aright )
# 2030 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 507 "c/cparser.mly"
                     ( Aand )
# 2036 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 508 "c/cparser.mly"
                     ( Axor )
# 2042 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    Obj.repr(
# 509 "c/cparser.mly"
                    ( Aor )
# 2048 "c/cparser.ml"
               : 'assignment_operator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 513 "c/cparser.mly"
                                ( _1 )
# 2055 "c/cparser.ml"
               : 'expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'expression) in
    let _3 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 514 "c/cparser.mly"
                                                 ( locate (CEseq (_1, _3)) )
# 2063 "c/cparser.ml"
               : 'expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'conditional_expression) in
    Obj.repr(
# 518 "c/cparser.mly"
                                 ( _1 )
# 2070 "c/cparser.ml"
               : 'constant_expression))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'declaration_specifiers) in
    Obj.repr(
# 523 "c/cparser.mly"
            ( type_declarations _1 )
# 2077 "c/cparser.ml"
               : 'declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'declaration_specifiers) in
    let _2 = (peek_val parser_env 2 : 'init_declarator_list) in
    let _3 = (peek_val parser_env 1 : 'attributes_opt) in
    Obj.repr(
# 525 "c/cparser.mly"
     ( List.map locate (declaration _1 _2) )
# 2086 "c/cparser.ml"
               : 'declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : int * Cast.parsed_spec) in
    let _2 = (peek_val parser_env 3 : 'declaration_specifiers) in
    let _3 = (peek_val parser_env 2 : 'init_declarator_list) in
    let _4 = (peek_val parser_env 1 : 'attributes_opt) in
    Obj.repr(
# 528 "c/cparser.mly"
     ( [locate (spec_declaration _1 _2 _3)] )
# 2096 "c/cparser.ml"
               : 'declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int * Cast.parsed_decl) in
    Obj.repr(
# 530 "c/cparser.mly"
     ( let ofs,d = _1 in [locate (Cspecdecl (ofs,d))] )
# 2103 "c/cparser.ml"
               : 'declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'storage_class_specifier) in
    Obj.repr(
# 535 "c/cparser.mly"
                                              ( [_1] )
# 2110 "c/cparser.ml"
               : 'declaration_specifiers))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'storage_class_specifier) in
    let _2 = (peek_val parser_env 0 : 'declaration_specifiers) in
    Obj.repr(
# 536 "c/cparser.mly"
                                                         ( _1 :: _2 )
# 2118 "c/cparser.ml"
               : 'declaration_specifiers))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_specifier) in
    Obj.repr(
# 537 "c/cparser.mly"
                         ( [_1] )
# 2125 "c/cparser.ml"
               : 'declaration_specifiers))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_specifier) in
    let _2 = (peek_val parser_env 0 : 'declaration_specifiers_no_name) in
    Obj.repr(
# 538 "c/cparser.mly"
                                                        ( _1 :: _2 )
# 2133 "c/cparser.ml"
               : 'declaration_specifiers))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_qualifier) in
    Obj.repr(
# 539 "c/cparser.mly"
                                     ( [_1] )
# 2140 "c/cparser.ml"
               : 'declaration_specifiers))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_qualifier) in
    let _2 = (peek_val parser_env 0 : 'declaration_specifiers) in
    Obj.repr(
# 540 "c/cparser.mly"
                                                ( _1 :: _2 )
# 2148 "c/cparser.ml"
               : 'declaration_specifiers))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'storage_class_specifier) in
    Obj.repr(
# 544 "c/cparser.mly"
                                              ( [_1] )
# 2155 "c/cparser.ml"
               : 'declaration_specifiers_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'storage_class_specifier) in
    let _2 = (peek_val parser_env 0 : 'declaration_specifiers_no_name) in
    Obj.repr(
# 545 "c/cparser.mly"
                                                                 ( _1 :: _2 )
# 2163 "c/cparser.ml"
               : 'declaration_specifiers_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_specifier_no_name) in
    Obj.repr(
# 546 "c/cparser.mly"
                                 ( [_1] )
# 2170 "c/cparser.ml"
               : 'declaration_specifiers_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_specifier_no_name) in
    let _2 = (peek_val parser_env 0 : 'declaration_specifiers_no_name) in
    Obj.repr(
# 547 "c/cparser.mly"
                                                                ( _1 :: _2 )
# 2178 "c/cparser.ml"
               : 'declaration_specifiers_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_qualifier) in
    Obj.repr(
# 548 "c/cparser.mly"
                                     ( [_1] )
# 2185 "c/cparser.ml"
               : 'declaration_specifiers_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_qualifier) in
    let _2 = (peek_val parser_env 0 : 'declaration_specifiers) in
    Obj.repr(
# 549 "c/cparser.mly"
                                                ( _1 :: _2 )
# 2193 "c/cparser.ml"
               : 'declaration_specifiers_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'init_declarator) in
    Obj.repr(
# 553 "c/cparser.mly"
                          ( [_1] )
# 2200 "c/cparser.ml"
               : 'init_declarator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'init_declarator_list) in
    let _3 = (peek_val parser_env 0 : 'init_declarator) in
    Obj.repr(
# 554 "c/cparser.mly"
                                                     ( _1 @ [_3] )
# 2208 "c/cparser.ml"
               : 'init_declarator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declarator) in
    Obj.repr(
# 559 "c/cparser.mly"
            ( _1, Inothing )
# 2215 "c/cparser.ml"
               : 'init_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'declarator) in
    let _3 = (peek_val parser_env 0 : 'c_initializer) in
    Obj.repr(
# 561 "c/cparser.mly"
     ( _1, _3 )
# 2223 "c/cparser.ml"
               : 'init_declarator))
; (fun parser_env ->
    Obj.repr(
# 565 "c/cparser.mly"
                  ( Stypedef )
# 2229 "c/cparser.ml"
               : 'storage_class_specifier))
; (fun parser_env ->
    Obj.repr(
# 566 "c/cparser.mly"
                 ( Sstorage Extern )
# 2235 "c/cparser.ml"
               : 'storage_class_specifier))
; (fun parser_env ->
    Obj.repr(
# 567 "c/cparser.mly"
                 ( Sstorage Static )
# 2241 "c/cparser.ml"
               : 'storage_class_specifier))
; (fun parser_env ->
    Obj.repr(
# 568 "c/cparser.mly"
               ( Sstorage Auto )
# 2247 "c/cparser.ml"
               : 'storage_class_specifier))
; (fun parser_env ->
    Obj.repr(
# 569 "c/cparser.mly"
                   ( Sstorage Register )
# 2253 "c/cparser.ml"
               : 'storage_class_specifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_specifier_no_name) in
    Obj.repr(
# 573 "c/cparser.mly"
                                 ( _1 )
# 2260 "c/cparser.ml"
               : 'type_specifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 574 "c/cparser.mly"
                    ( Stype (CTvar _1) )
# 2267 "c/cparser.ml"
               : 'type_specifier))
; (fun parser_env ->
    Obj.repr(
# 577 "c/cparser.mly"
               ( Stype CTvoid )
# 2273 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 578 "c/cparser.mly"
               ( Stype (CTint (Unsigned, Char)) )
# 2279 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 579 "c/cparser.mly"
                ( Sshort )
# 2285 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 580 "c/cparser.mly"
              ( Stype (CTint (Signed, Int)) )
# 2291 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 581 "c/cparser.mly"
               ( Slong )
# 2297 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 582 "c/cparser.mly"
                ( Stype (CTfloat Float) )
# 2303 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 583 "c/cparser.mly"
                 ( Stype (CTfloat Double) )
# 2309 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 584 "c/cparser.mly"
                 ( Ssign Signed )
# 2315 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    Obj.repr(
# 585 "c/cparser.mly"
                   ( Ssign Unsigned )
# 2321 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'struct_or_union_specifier) in
    Obj.repr(
# 586 "c/cparser.mly"
                                    ( _1 )
# 2328 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'enum_specifier) in
    Obj.repr(
# 587 "c/cparser.mly"
                         ( _1 )
# 2335 "c/cparser.ml"
               : 'type_specifier_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 591 "c/cparser.mly"
                     ( _1 )
# 2342 "c/cparser.ml"
               : 'identifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 592 "c/cparser.mly"
                     ( _1 )
# 2349 "c/cparser.ml"
               : 'identifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'struct_or_union) in
    let _2 = (peek_val parser_env 3 : 'identifier) in
    let _4 = (peek_val parser_env 1 : 'struct_declaration_list) in
    Obj.repr(
# 597 "c/cparser.mly"
            ( if _1 then 
		Sstruct_decl (Some _2, _4) 
	      else 
		Sunion_decl (Some _2, _4) )
# 2361 "c/cparser.ml"
               : 'struct_or_union_specifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'struct_or_union) in
    let _3 = (peek_val parser_env 1 : 'struct_declaration_list) in
    Obj.repr(
# 602 "c/cparser.mly"
     ( if _1 then Sstruct_decl (None, _3) else Sunion_decl (None, _3) )
# 2369 "c/cparser.ml"
               : 'struct_or_union_specifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'struct_or_union) in
    let _2 = (peek_val parser_env 0 : 'identifier) in
    Obj.repr(
# 604 "c/cparser.mly"
     ( Stype (if _1 then CTstruct (_2, Tag) else CTunion (_2, Tag)) )
# 2377 "c/cparser.ml"
               : 'struct_or_union_specifier))
; (fun parser_env ->
    Obj.repr(
# 608 "c/cparser.mly"
                 ( true )
# 2383 "c/cparser.ml"
               : 'struct_or_union))
; (fun parser_env ->
    Obj.repr(
# 609 "c/cparser.mly"
                ( false )
# 2389 "c/cparser.ml"
               : 'struct_or_union))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'struct_declaration) in
    Obj.repr(
# 613 "c/cparser.mly"
                             ( _1 )
# 2396 "c/cparser.ml"
               : 'struct_declaration_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'struct_declaration_list) in
    let _2 = (peek_val parser_env 0 : 'struct_declaration) in
    Obj.repr(
# 614 "c/cparser.mly"
                                                     ( _1 @ _2 )
# 2404 "c/cparser.ml"
               : 'struct_declaration_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'specifier_qualifier_list) in
    let _2 = (peek_val parser_env 1 : 'struct_declarator_list) in
    Obj.repr(
# 619 "c/cparser.mly"
            ( let s = _1 in List.map (fun ((id,d),bf) -> s,d,id,bf) _2 )
# 2412 "c/cparser.ml"
               : 'struct_declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_specifier) in
    let _2 = (peek_val parser_env 0 : 'specifier_qualifier_list_no_name) in
    Obj.repr(
# 623 "c/cparser.mly"
                                                          ( _1 :: _2 )
# 2420 "c/cparser.ml"
               : 'specifier_qualifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_specifier) in
    Obj.repr(
# 624 "c/cparser.mly"
                         ( [_1] )
# 2427 "c/cparser.ml"
               : 'specifier_qualifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_qualifier) in
    let _2 = (peek_val parser_env 0 : 'specifier_qualifier_list) in
    Obj.repr(
# 625 "c/cparser.mly"
                                                  ( _1 :: _2 )
# 2435 "c/cparser.ml"
               : 'specifier_qualifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_qualifier) in
    Obj.repr(
# 626 "c/cparser.mly"
                                     ( [_1] )
# 2442 "c/cparser.ml"
               : 'specifier_qualifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_specifier_no_name) in
    let _2 = (peek_val parser_env 0 : 'specifier_qualifier_list_no_name) in
    Obj.repr(
# 630 "c/cparser.mly"
                                                                  ( _1 :: _2 )
# 2450 "c/cparser.ml"
               : 'specifier_qualifier_list_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_specifier_no_name) in
    Obj.repr(
# 631 "c/cparser.mly"
                                 ( [_1] )
# 2457 "c/cparser.ml"
               : 'specifier_qualifier_list_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_qualifier) in
    let _2 = (peek_val parser_env 0 : 'specifier_qualifier_list_no_name) in
    Obj.repr(
# 632 "c/cparser.mly"
                                                          ( _1 :: _2 )
# 2465 "c/cparser.ml"
               : 'specifier_qualifier_list_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_qualifier) in
    Obj.repr(
# 633 "c/cparser.mly"
                         ( [_1] )
# 2472 "c/cparser.ml"
               : 'specifier_qualifier_list_no_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'struct_declarator) in
    Obj.repr(
# 637 "c/cparser.mly"
                            ( [_1] )
# 2479 "c/cparser.ml"
               : 'struct_declarator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'struct_declarator_list) in
    let _3 = (peek_val parser_env 0 : 'struct_declarator) in
    Obj.repr(
# 638 "c/cparser.mly"
                                                         ( _1 @ [_3] )
# 2487 "c/cparser.ml"
               : 'struct_declarator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declarator) in
    Obj.repr(
# 643 "c/cparser.mly"
            ( _1, None )
# 2494 "c/cparser.ml"
               : 'struct_declarator))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'constant_expression) in
    Obj.repr(
# 645 "c/cparser.mly"
     ( ("_", Dsimple), Some _2 )
# 2501 "c/cparser.ml"
               : 'struct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'declarator) in
    let _3 = (peek_val parser_env 0 : 'constant_expression) in
    Obj.repr(
# 647 "c/cparser.mly"
     ( _1, Some _3 )
# 2509 "c/cparser.ml"
               : 'struct_declarator))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : 'enumerator_list) in
    Obj.repr(
# 652 "c/cparser.mly"
            ( Stype (CTenum (fresh_name None, Decl _3)) )
# 2516 "c/cparser.ml"
               : 'enum_specifier))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : 'identifier) in
    let _4 = (peek_val parser_env 1 : 'enumerator_list) in
    Obj.repr(
# 654 "c/cparser.mly"
     ( Stype (CTenum (_2, Decl _4)) )
# 2524 "c/cparser.ml"
               : 'enum_specifier))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'identifier) in
    Obj.repr(
# 656 "c/cparser.mly"
     ( Stype (CTenum (_2, Tag)) )
# 2531 "c/cparser.ml"
               : 'enum_specifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'enumerator) in
    Obj.repr(
# 660 "c/cparser.mly"
                     ( [_1] )
# 2538 "c/cparser.ml"
               : 'enumerator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'enumerator_list) in
    let _3 = (peek_val parser_env 0 : 'enumerator) in
    Obj.repr(
# 661 "c/cparser.mly"
                                           ( _1 @ [_3] )
# 2546 "c/cparser.ml"
               : 'enumerator_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 665 "c/cparser.mly"
                     ( _1, None )
# 2553 "c/cparser.ml"
               : 'enumerator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : string) in
    let _3 = (peek_val parser_env 0 : 'constant_expression) in
    Obj.repr(
# 666 "c/cparser.mly"
                                               ( _1, Some _3 )
# 2561 "c/cparser.ml"
               : 'enumerator))
; (fun parser_env ->
    Obj.repr(
# 670 "c/cparser.mly"
                ( Sconst )
# 2567 "c/cparser.ml"
               : 'type_qualifier))
; (fun parser_env ->
    Obj.repr(
# 671 "c/cparser.mly"
                   ( Svolatile )
# 2573 "c/cparser.ml"
               : 'type_qualifier))
; (fun parser_env ->
    Obj.repr(
# 672 "c/cparser.mly"
            ( dwarning "ignored __restrict"; Srestrict )
# 2579 "c/cparser.ml"
               : 'type_qualifier))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'pointer) in
    let _2 = (peek_val parser_env 0 : 'direct_declarator) in
    Obj.repr(
# 676 "c/cparser.mly"
                                    ( let id,d = _2 in id, _1 d )
# 2587 "c/cparser.ml"
               : 'declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'direct_declarator) in
    Obj.repr(
# 677 "c/cparser.mly"
                            ( _1 )
# 2594 "c/cparser.ml"
               : 'declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'identifier) in
    Obj.repr(
# 682 "c/cparser.mly"
            ( _1, Dsimple )
# 2601 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'declarator) in
    Obj.repr(
# 684 "c/cparser.mly"
     ( _2 )
# 2608 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'direct_declarator) in
    let _3 = (peek_val parser_env 1 : 'constant_expression) in
    Obj.repr(
# 686 "c/cparser.mly"
     ( let id,d = _1 in id, Darray (d, Some _3) )
# 2616 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'direct_declarator) in
    Obj.repr(
# 688 "c/cparser.mly"
     ( let id,d = _1 in id, Darray (d, None) )
# 2623 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'direct_declarator) in
    let _3 = (peek_val parser_env 1 : 'parameter_type_list) in
    Obj.repr(
# 690 "c/cparser.mly"
     ( let id,d = _1 in id, Dfunction (d, _3) )
# 2631 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'direct_declarator) in
    let _3 = (peek_val parser_env 1 : 'identifier_list) in
    Obj.repr(
# 692 "c/cparser.mly"
     ( let pl = List.map (fun x -> ([], Dsimple, x)) _3 in
	      let id,d = _1 in id, Dfunction (d, pl) )
# 2640 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'direct_declarator) in
    Obj.repr(
# 695 "c/cparser.mly"
            ( let id,d = _1 in id, Dfunction (d, []) )
# 2647 "c/cparser.ml"
               : 'direct_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int * Cast.parsed_loop_annot) in
    Obj.repr(
# 700 "c/cparser.mly"
                                       ( _1 )
# 2654 "c/cparser.ml"
               : 'loop_annot))
; (fun parser_env ->
    Obj.repr(
# 701 "c/cparser.mly"
                                       ( symbol_start (), no_loop_annot )
# 2660 "c/cparser.ml"
               : 'loop_annot))
; (fun parser_env ->
    Obj.repr(
# 705 "c/cparser.mly"
               ( fun d -> Dpointer d )
# 2666 "c/cparser.ml"
               : 'pointer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'type_qualifier_list) in
    Obj.repr(
# 707 "c/cparser.mly"
     ( dwarning "ignored qualifiers"; fun d -> Dpointer d )
# 2673 "c/cparser.ml"
               : 'pointer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 0 : 'pointer) in
    Obj.repr(
# 708 "c/cparser.mly"
                       ( fun d -> Dpointer (_2 d) )
# 2680 "c/cparser.ml"
               : 'pointer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'type_qualifier_list) in
    let _3 = (peek_val parser_env 0 : 'pointer) in
    Obj.repr(
# 710 "c/cparser.mly"
     ( dwarning "ignored qualifiers"; fun d -> Dpointer (_3 d) )
# 2688 "c/cparser.ml"
               : 'pointer))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'type_qualifier) in
    Obj.repr(
# 714 "c/cparser.mly"
                         ( [_1] )
# 2695 "c/cparser.ml"
               : 'type_qualifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'type_qualifier_list) in
    let _2 = (peek_val parser_env 0 : 'type_qualifier) in
    Obj.repr(
# 715 "c/cparser.mly"
                                             ( _1 @ [_2] )
# 2703 "c/cparser.ml"
               : 'type_qualifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'parameter_list) in
    Obj.repr(
# 720 "c/cparser.mly"
                         ( _1 )
# 2710 "c/cparser.ml"
               : 'parameter_type_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'parameter_list) in
    Obj.repr(
# 722 "c/cparser.mly"
                                        ( dwarning "ignored <...>"; _1 )
# 2717 "c/cparser.ml"
               : 'parameter_type_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'parameter_declaration) in
    Obj.repr(
# 726 "c/cparser.mly"
                                ( [_1] )
# 2724 "c/cparser.ml"
               : 'parameter_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'parameter_list) in
    let _3 = (peek_val parser_env 0 : 'parameter_declaration) in
    Obj.repr(
# 727 "c/cparser.mly"
                                                     ( _1 @ [_3] )
# 2732 "c/cparser.ml"
               : 'parameter_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'declaration_specifiers) in
    let _2 = (peek_val parser_env 0 : 'declarator) in
    Obj.repr(
# 732 "c/cparser.mly"
            ( let id,d = _2 in _1, d, id )
# 2740 "c/cparser.ml"
               : 'parameter_declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'declaration_specifiers) in
    let _2 = (peek_val parser_env 0 : 'abstract_declarator) in
    Obj.repr(
# 734 "c/cparser.mly"
     ( _1, _2, "_" )
# 2748 "c/cparser.ml"
               : 'parameter_declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declaration_specifiers) in
    Obj.repr(
# 736 "c/cparser.mly"
     ( (_1, Dsimple, "_") )
# 2755 "c/cparser.ml"
               : 'parameter_declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 740 "c/cparser.mly"
                     ( [_1] )
# 2762 "c/cparser.ml"
               : 'identifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'identifier_list) in
    let _3 = (peek_val parser_env 0 : string) in
    Obj.repr(
# 741 "c/cparser.mly"
                                           ( _1 @ [_3] )
# 2770 "c/cparser.ml"
               : 'identifier_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'specifier_qualifier_list) in
    Obj.repr(
# 745 "c/cparser.mly"
                                   ( _1, Dsimple )
# 2777 "c/cparser.ml"
               : 'type_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'specifier_qualifier_list) in
    let _2 = (peek_val parser_env 0 : 'abstract_declarator) in
    Obj.repr(
# 746 "c/cparser.mly"
                                                       ( _1, _2 )
# 2785 "c/cparser.ml"
               : 'type_name))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'pointer) in
    Obj.repr(
# 750 "c/cparser.mly"
                  ( _1 Dsimple )
# 2792 "c/cparser.ml"
               : 'abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'direct_abstract_declarator) in
    Obj.repr(
# 751 "c/cparser.mly"
                                     ( _1 )
# 2799 "c/cparser.ml"
               : 'abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'pointer) in
    let _2 = (peek_val parser_env 0 : 'direct_abstract_declarator) in
    Obj.repr(
# 752 "c/cparser.mly"
                                             ( _1 _2 )
# 2807 "c/cparser.ml"
               : 'abstract_declarator))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'abstract_declarator) in
    Obj.repr(
# 757 "c/cparser.mly"
            ( _2 )
# 2814 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    Obj.repr(
# 759 "c/cparser.mly"
     ( Darray (Dsimple, None) )
# 2820 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'constant_expression) in
    Obj.repr(
# 761 "c/cparser.mly"
     ( Darray (Dsimple, Some _2) )
# 2827 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'direct_abstract_declarator) in
    Obj.repr(
# 763 "c/cparser.mly"
     ( Darray (_1, None) )
# 2834 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'direct_abstract_declarator) in
    let _3 = (peek_val parser_env 1 : 'constant_expression) in
    Obj.repr(
# 765 "c/cparser.mly"
     ( Darray (_1, Some _3) )
# 2842 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    Obj.repr(
# 767 "c/cparser.mly"
     ( Dfunction (Dsimple, []) )
# 2848 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'parameter_type_list) in
    Obj.repr(
# 769 "c/cparser.mly"
     ( Dfunction (Dsimple, _2) )
# 2855 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'direct_abstract_declarator) in
    Obj.repr(
# 771 "c/cparser.mly"
     ( Dfunction (_1, []) )
# 2862 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'direct_abstract_declarator) in
    let _3 = (peek_val parser_env 1 : 'parameter_type_list) in
    Obj.repr(
# 773 "c/cparser.mly"
     ( Dfunction (_1, _3) )
# 2870 "c/cparser.ml"
               : 'direct_abstract_declarator))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'assignment_expression) in
    Obj.repr(
# 777 "c/cparser.mly"
                                ( Iexpr _1 )
# 2877 "c/cparser.ml"
               : 'c_initializer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'c_initializer_list) in
    Obj.repr(
# 778 "c/cparser.mly"
                                           ( Ilist _2 )
# 2884 "c/cparser.ml"
               : 'c_initializer))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'c_initializer_list) in
    Obj.repr(
# 779 "c/cparser.mly"
                                                 ( Ilist _2 )
# 2891 "c/cparser.ml"
               : 'c_initializer))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'c_initializer) in
    Obj.repr(
# 783 "c/cparser.mly"
                        ( [_1] )
# 2898 "c/cparser.ml"
               : 'c_initializer_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'c_initializer_list) in
    let _3 = (peek_val parser_env 0 : 'c_initializer) in
    Obj.repr(
# 784 "c/cparser.mly"
                                                 ( _1 @ [_3] )
# 2906 "c/cparser.ml"
               : 'c_initializer_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'labeled_statement) in
    Obj.repr(
# 788 "c/cparser.mly"
                            ( _1 )
# 2913 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'compound_statement) in
    Obj.repr(
# 789 "c/cparser.mly"
                             ( locate (CSblock _1) )
# 2920 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'expression_statement) in
    Obj.repr(
# 790 "c/cparser.mly"
                               ( _1 )
# 2927 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'selection_statement) in
    Obj.repr(
# 791 "c/cparser.mly"
                              ( _1 )
# 2934 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'iteration_statement) in
    Obj.repr(
# 792 "c/cparser.mly"
                              ( _1 )
# 2941 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'jump_statement) in
    Obj.repr(
# 793 "c/cparser.mly"
                         ( _1 )
# 2948 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : int * Cast.parsed_spec) in
    let _2 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 794 "c/cparser.mly"
                  ( locate (CSspec (_1,_2)) )
# 2956 "c/cparser.ml"
               : 'statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'identifier) in
    let _3 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 798 "c/cparser.mly"
                                            ( locate (CSlabel (_1, _3)) )
# 2964 "c/cparser.ml"
               : 'labeled_statement))
; (fun parser_env ->
    let _2 = (peek_val parser_env 2 : 'constant_expression) in
    let _4 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 799 "c/cparser.mly"
                                                   ( locate (CScase (_2, _4)) )
# 2972 "c/cparser.ml"
               : 'labeled_statement))
; (fun parser_env ->
    let _3 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 800 "c/cparser.mly"
                                  ( locate (CSlabel ("%default%", _3)) )
# 2979 "c/cparser.ml"
               : 'labeled_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'compound_statement_LBRACE) in
    Obj.repr(
# 805 "c/cparser.mly"
            ( Ctypes.pop (); [], [] )
# 2986 "c/cparser.ml"
               : 'compound_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'compound_statement_LBRACE) in
    let _2 = (peek_val parser_env 1 : 'statement_list) in
    Obj.repr(
# 807 "c/cparser.mly"
     ( Ctypes.pop (); [], _2 )
# 2994 "c/cparser.ml"
               : 'compound_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'compound_statement_LBRACE) in
    let _2 = (peek_val parser_env 1 : 'declaration_list) in
    Obj.repr(
# 809 "c/cparser.mly"
     ( Ctypes.pop (); _2, [] )
# 3002 "c/cparser.ml"
               : 'compound_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'compound_statement_LBRACE) in
    let _2 = (peek_val parser_env 2 : 'declaration_list) in
    let _3 = (peek_val parser_env 1 : 'statement_list) in
    Obj.repr(
# 811 "c/cparser.mly"
     ( Ctypes.pop (); _2, _3 )
# 3011 "c/cparser.ml"
               : 'compound_statement))
; (fun parser_env ->
    Obj.repr(
# 815 "c/cparser.mly"
         ( Ctypes.push () )
# 3017 "c/cparser.ml"
               : 'compound_statement_LBRACE))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declaration) in
    Obj.repr(
# 819 "c/cparser.mly"
                      ( _1 )
# 3024 "c/cparser.ml"
               : 'declaration_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'declaration_list) in
    let _2 = (peek_val parser_env 0 : 'declaration) in
    Obj.repr(
# 820 "c/cparser.mly"
                                       ( _1 @ _2 )
# 3032 "c/cparser.ml"
               : 'declaration_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 824 "c/cparser.mly"
                    ( [_1] )
# 3039 "c/cparser.ml"
               : 'statement_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'statement_list) in
    let _2 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 825 "c/cparser.mly"
                                   ( _1 @ [_2] )
# 3047 "c/cparser.ml"
               : 'statement_list))
; (fun parser_env ->
    Obj.repr(
# 829 "c/cparser.mly"
                    ( locate CSnop )
# 3053 "c/cparser.ml"
               : 'expression_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : int * Cast.parsed_code_annot) in
    Obj.repr(
# 830 "c/cparser.mly"
              ( locate (CSannot _1) )
# 3060 "c/cparser.ml"
               : 'expression_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'expression) in
    Obj.repr(
# 831 "c/cparser.mly"
                               ( locate (CSexpr _1) )
# 3067 "c/cparser.ml"
               : 'expression_statement))
; (fun parser_env ->
    let _3 = (peek_val parser_env 2 : 'expression) in
    let _5 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 836 "c/cparser.mly"
            ( locate (CSif (_3, _5, locate CSnop)) )
# 3075 "c/cparser.ml"
               : 'selection_statement))
; (fun parser_env ->
    let _3 = (peek_val parser_env 4 : 'expression) in
    let _5 = (peek_val parser_env 2 : 'statement) in
    let _7 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 838 "c/cparser.mly"
     ( locate (CSif (_3, _5, _7)) )
# 3084 "c/cparser.ml"
               : 'selection_statement))
; (fun parser_env ->
    let _3 = (peek_val parser_env 2 : 'expression) in
    let _5 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 840 "c/cparser.mly"
     ( locate (CSswitch (_3, _5)) )
# 3092 "c/cparser.ml"
               : 'selection_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 5 : 'loop_annot) in
    let _4 = (peek_val parser_env 2 : 'expression) in
    let _6 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 845 "c/cparser.mly"
            ( locate (CSwhile (_1, _4, _6)) )
# 3101 "c/cparser.ml"
               : 'iteration_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 7 : 'loop_annot) in
    let _3 = (peek_val parser_env 5 : 'statement) in
    let _6 = (peek_val parser_env 2 : 'expression) in
    Obj.repr(
# 847 "c/cparser.mly"
     ( locate (CSdowhile (_1, _3, _6)) )
# 3110 "c/cparser.ml"
               : 'iteration_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 6 : 'loop_annot) in
    let _4 = (peek_val parser_env 3 : 'expression_statement) in
    let _5 = (peek_val parser_env 2 : 'expression_statement) in
    let _7 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 850 "c/cparser.mly"
     ( locate (CSfor (_1, expr_of_statement _4, expr_of_statement _5, 
			     locate CEnop, _7)) )
# 3121 "c/cparser.ml"
               : 'iteration_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 7 : 'loop_annot) in
    let _4 = (peek_val parser_env 4 : 'expression_statement) in
    let _5 = (peek_val parser_env 3 : 'expression_statement) in
    let _6 = (peek_val parser_env 2 : 'expression) in
    let _8 = (peek_val parser_env 0 : 'statement) in
    Obj.repr(
# 855 "c/cparser.mly"
     ( locate (CSfor (_1, expr_of_statement _4, expr_of_statement _5, 
			     _6, _8)) )
# 3133 "c/cparser.ml"
               : 'iteration_statement))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'identifier) in
    Obj.repr(
# 860 "c/cparser.mly"
                                           ( locate (CSgoto _2) )
# 3140 "c/cparser.ml"
               : 'jump_statement))
; (fun parser_env ->
    Obj.repr(
# 861 "c/cparser.mly"
                             ( locate CScontinue )
# 3146 "c/cparser.ml"
               : 'jump_statement))
; (fun parser_env ->
    Obj.repr(
# 862 "c/cparser.mly"
                          ( locate CSbreak )
# 3152 "c/cparser.ml"
               : 'jump_statement))
; (fun parser_env ->
    Obj.repr(
# 863 "c/cparser.mly"
                           ( locate (CSreturn None) )
# 3158 "c/cparser.ml"
               : 'jump_statement))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'expression) in
    Obj.repr(
# 864 "c/cparser.mly"
                                      ( locate (CSreturn (Some _2)) )
# 3165 "c/cparser.ml"
               : 'jump_statement))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'external_declaration) in
    Obj.repr(
# 868 "c/cparser.mly"
                               ( _1 )
# 3172 "c/cparser.ml"
               : 'translation_unit))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'translation_unit) in
    let _2 = (peek_val parser_env 0 : 'external_declaration) in
    Obj.repr(
# 869 "c/cparser.mly"
                                                ( _1 @ _2 )
# 3180 "c/cparser.ml"
               : 'translation_unit))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'function_definition) in
    Obj.repr(
# 873 "c/cparser.mly"
                              ( [_1] )
# 3187 "c/cparser.ml"
               : 'external_declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declaration) in
    Obj.repr(
# 874 "c/cparser.mly"
                      ( _1 )
# 3194 "c/cparser.ml"
               : 'external_declaration))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'function_prototype) in
    let _2 = (peek_val parser_env 0 : 'compound_statement) in
    Obj.repr(
# 879 "c/cparser.mly"
            ( Ctypes.pop (); (* pushed by function_prototype *)
	      let ty,id,pl = _1 in
	      let bl = locate_i 2 (CSblock _2) in
	      locate (Cfundef (None, ty, id, pl, bl)) )
# 3205 "c/cparser.ml"
               : 'function_definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : int * Cast.parsed_spec) in
    let _2 = (peek_val parser_env 1 : 'function_prototype) in
    let _3 = (peek_val parser_env 0 : 'compound_statement) in
    Obj.repr(
# 884 "c/cparser.mly"
            ( Ctypes.pop (); (* pushed by function_prototype *)
	      let ty,id,pl = _2 in
	      let bl = locate_i 3 (CSblock _3) in
	      locate (Cfundef (Some _1, ty, id, pl, bl)) )
# 3217 "c/cparser.ml"
               : 'function_definition))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'declaration_specifiers) in
    let _2 = (peek_val parser_env 1 : 'declarator) in
    let _3 = (peek_val parser_env 0 : 'declaration_list) in
    Obj.repr(
# 892 "c/cparser.mly"
            ( Ctypes.push (); function_declaration _1 _2 _3 )
# 3226 "c/cparser.ml"
               : 'function_prototype))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'declaration_specifiers) in
    let _2 = (peek_val parser_env 0 : 'declarator) in
    Obj.repr(
# 894 "c/cparser.mly"
     ( Ctypes.push (); function_declaration _1 _2 [] )
# 3234 "c/cparser.ml"
               : 'function_prototype))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'declarator) in
    let _2 = (peek_val parser_env 0 : 'declaration_list) in
    Obj.repr(
# 896 "c/cparser.mly"
     ( Ctypes.push (); function_declaration [] _1 _2 )
# 3242 "c/cparser.ml"
               : 'function_prototype))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'declarator) in
    Obj.repr(
# 898 "c/cparser.mly"
     ( Ctypes.push (); function_declaration [] _1 [] )
# 3249 "c/cparser.ml"
               : 'function_prototype))
; (fun parser_env ->
    Obj.repr(
# 904 "c/cparser.mly"
              ()
# 3255 "c/cparser.ml"
               : 'attributes_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'attributes) in
    Obj.repr(
# 905 "c/cparser.mly"
             ( dwarning "ignored attributes" )
# 3262 "c/cparser.ml"
               : 'attributes_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'attribute) in
    Obj.repr(
# 909 "c/cparser.mly"
            ()
# 3269 "c/cparser.ml"
               : 'attributes))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'attributes) in
    let _2 = (peek_val parser_env 0 : 'attribute) in
    Obj.repr(
# 910 "c/cparser.mly"
                       ()
# 3277 "c/cparser.ml"
               : 'attributes))
; (fun parser_env ->
    let _4 = (peek_val parser_env 2 : 'attribute_list) in
    Obj.repr(
# 914 "c/cparser.mly"
                                               ()
# 3284 "c/cparser.ml"
               : 'attribute))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'attrib) in
    Obj.repr(
# 918 "c/cparser.mly"
         ()
# 3291 "c/cparser.ml"
               : 'attribute_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'attribute_list) in
    let _3 = (peek_val parser_env 0 : 'attrib) in
    Obj.repr(
# 919 "c/cparser.mly"
                              ()
# 3299 "c/cparser.ml"
               : 'attribute_list))
; (fun parser_env ->
    Obj.repr(
# 923 "c/cparser.mly"
              ()
# 3305 "c/cparser.ml"
               : 'attrib))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'identifier) in
    Obj.repr(
# 924 "c/cparser.mly"
             ()
# 3312 "c/cparser.ml"
               : 'attrib))
; (fun parser_env ->
    let _1 = (peek_val parser_env 2 : 'identifier) in
    Obj.repr(
# 925 "c/cparser.mly"
                       ()
# 3319 "c/cparser.ml"
               : 'attrib))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : 'identifier) in
    let _3 = (peek_val parser_env 1 : 'argument_expression_list) in
    Obj.repr(
# 926 "c/cparser.mly"
                                                ()
# 3327 "c/cparser.ml"
               : 'attrib))
; (fun parser_env ->
    Obj.repr(
# 927 "c/cparser.mly"
        ()
# 3333 "c/cparser.ml"
               : 'attrib))
(* Entry file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
|]
let yytables =
  { actions=yyact;
    transl_const=yytransl_const;
    transl_block=yytransl_block;
    lhs=yylhs;
    len=yylen;
    defred=yydefred;
    dgoto=yydgoto;
    sindex=yysindex;
    rindex=yyrindex;
    gindex=yygindex;
    tablesize=yytablesize;
    table=yytable;
    check=yycheck;
    error_function=parse_error;
    names_const=yynames_const;
    names_block=yynames_block }
let file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 1 lexfun lexbuf : Cast.file)
